

function [fmin]=fobj(para,gn)
%this program is to find out the RNN parameters value.
% Default parameters
nf=20;           % Population size, typically 10 to 25
pf=0.8;           % probabibility switch

% Iteration parameters
N_iterf=2000;            % Total number of iterations

% Dimension of the search variables
df=5;
% Lower bounds 
Lbf=[-25 -25 -25 -10 0]; 
% Upper bounds
Ubf=[25	25	25	10 15];
% Initializing arrays
sf=para;

rand('state',0);
randn('state',0);
% Initialize the population/solutions
for i=1:nf,
  Sol(i,:)=Lbf+(Ubf-Lbf).*rand(1,df);
  Fitness(i)=Fun(Sol(i,:),sf,gn);
end

% Find the current best
[fmin,I]=min(Fitness);
best=Sol(I,:);
S=Sol; 

% Start the iterations -- Flower Algorithm 
for t=1:N_iterf,
        % Loop over all bats/solutions
        for i=1:nf,
          % Pollens are carried by insects and thus can move in
          % large scale, large distance.
          % This L should replace by Levy flights  
          % Formula: x_i^{t+1}=x_i^t+ L (x_i^t-gbest)
          if rand>pf,
          %% L=rand;
          L=Levy(df);
          dS=L.*(Sol(i,:)-best);
          S(i,:)=Sol(i,:)+dS;
          
          % Check if the simple limits/bounds are OK
          S(i,:)=simplebounds(S(i,:),Lbf,Ubf);
          
          % If not, then local pollenation of neighbor flowers 
          else
              epsilon=rand;
              % Find random flowers in the neighbourhood
              JK=randperm(nf);
              % As they are random, the first two entries also random
              % If the flower are the same or similar species, then
              % they can be pollenated, otherwise, no action.
              % Formula: x_i^{t+1}+epsilon*(x_j^t-x_k^t)
              S(i,:)=S(i,:)+epsilon*(Sol(JK(1),:)-Sol(JK(2),:));
              % Check if the simple limits/bounds are OK
              S(i,:)=simplebounds(S(i,:),Lbf,Ubf);
          end
          
          % Evaluate new solutions
           Fnew=Fun(S(i,:),sf,gn);
          % If fitness improves (better solutions found), update then
            if (Fnew<=Fitness(i)),
                Sol(i,:)=S(i,:);
                Fitness(i)=Fnew;
           end
           
          % Update the current global best
          if Fnew<=fmin,
                best=S(i,:)   ;
                fmin=Fnew   ;
          end
        end
         bestdisp(t)=fmin;
         if ((bestdisp(t) < 1*10^(-8))|| ((t>500) && (bestdisp(t-200)-bestdisp(t))<1*10^(-10)))
            break;
       else 
           continue;
        end
               
      
end
t
sf
best
fmin


  

% Application of simple constraints
function s=simplebounds(s,Lbf,Ubf)
  % Apply the lower bound
  ns_tmp=s;
  I=ns_tmp<Lbf;
  ns_tmp(I)=Lbf(I);
  
  % Apply the upper bounds 
  J=ns_tmp>Ubf;
  ns_tmp(J)=Ubf(J);
  % Update this new move 
  s=ns_tmp;


% Draw n Levy flight sample
function L=Levy(df)
beta=3/2;
sigma=(gamma(1+beta)*sin(pi*beta/2)/(gamma((1+beta)/2)*beta*2^((beta-1)/2)))^(1/beta);
    u=randn(1,df)*sigma;
    v=randn(1,df);
    step=u./abs(v).^(1/beta);
L=0.01*step; 

% Objective function and here we used Rosenbrock's 3D function
function z=Fun(u,sf,gn)
d2=[0.814723686	0.905791937	0.126986816	0.913375856	0.632359246	0.097540405	0.278498219	0.546881519	0.957506835	0.964888535	0.157613082	0.970592782	0.957166948	0.485375649	0.800280469	0.141886339	0.421761283	0.915735525	0.79220733	0.959492426	0.655740699	0.035711679	0.849129306	0.933993248	0.678735155	0.757740131	0.743132468	0.39222702	0.65547789	0.171186688
0.733320145	0.914543458	0.164288135	0.872038271	0.669123127	0.087787609	0.350648362	0.592193366	0.861814021	0.958558685	0.141856054	0.973512983	0.961448476	0.536838026	0.720252465	0.127772704	0.379585154	0.874161973	0.713055424	0.963509743	0.595698551	0.082140511	0.76566836	0.840594069	0.610868446	0.781966117	0.668825633	0.353563397	0.689878938	0.254066577
0.660019949	0.922419827	0.197859321	0.834834443	0.702210374	0.079015185	0.415583504	0.632974027	0.77564913	0.944363364	0.127682152	0.97611442	0.96530291	0.58315398	0.648227265	0.115052118	0.341626639	0.836745775	0.6417817	0.967084353	0.543334788	0.12392646	0.691298547	0.756535002	0.54978814	0.803769505	0.601988822	0.319739255	0.720850885	0.328655524
0.59403384	0.92950856	0.228073389	0.801350999	0.73198842	0.071141113	0.47402514	0.669676619	0.698089556	0.919861195	0.114942869	0.978403598	0.968772301	0.624837697	0.583404592	0.103590986	0.307463975	0.803071198	0.577619416	0.970223119	0.498104977	0.161533814	0.625347787	0.680882229	0.494815636	0.823392551	0.542057658	0.291509454	0.748733502	0.395777995
0.534638958	0.935888418	0.25526605	0.771215899	0.758787805	0.064129642	0.526622617	0.702708946	0.628282534	0.884332525	0.103513907	0.980371233	0.971894919	0.662351094	0.525064201	0.093267074	0.276717578	0.772764078	0.519865976	0.97290904	0.459481091	0.195380432	0.567229563	0.612795446	0.445340186	0.841053282	0.489153578	0.270507793	0.773833609	0.456170773
0.481179906	0.941630292	0.279739445	0.744094309	0.782905814	0.058052567	0.573960349	0.732438031	0.565455056	0.839282652	0.093298422	0.981991293	0.974705348	0.696107911	0.472557878	0.08396915	0.24904582	0.74548767	0.467884222	0.975096456	0.426941149	0.225842389	0.516418999	0.551518565	0.40081212	0.856947909	0.445473543	0.259165199	0.796428002	0.510488658
0.433064834	0.946797977	0.301765501	0.719684878	0.804609753	0.053219506	0.61656431	0.759194194	0.508909892	0.787663473	0.084231185	0.983223645	0.97723477	0.726476404	0.425302243	0.075596337	0.224141238	0.720938903	0.421098719	0.976708043	0.399964753	0.25325815	0.47243008	0.496371341	0.360736732	0.871253008	0.417622189	0.259903988	0.816766224	0.559314635
0.389760202	0.951448894	0.321588951	0.697716391	0.824139912	0.050403083	0.654907876	0.783274718	0.458019067	0.732661467	0.076282674	0.984021399	0.979511267	0.753780398	0.382772274	0.068057355	0.201727114	0.698845013	0.378990698	0.977635061	0.37803362	0.277932335	0.434796352	0.446741829	0.324668789	0.884127522	0.414832114	0.273779604	0.835073154	0.603193234
0.350785411	0.95563472	0.339430056	0.677944751	0.841712251	0.051121163	0.689417085	0.804947159	0.412217247	0.676917257	0.069461715	0.98434246	0.981560125	0.778298648	0.34449549	0.061269733	0.181554403	0.678960512	0.341092857	0.977741981	0.360635651	0.300139102	0.403056862	0.402079577	0.292207587	0.895714551	0.437764743	0.299646281	0.851551376	0.642675873
0.31570772	0.959401963	0.35548705	0.660150276	0.857520842	0.057765397	0.720475375	0.824452314	0.370995572	0.622302495	0.063815184	0.984162797	0.983404102	0.800262839	0.310046715	0.055159034	0.163398962	0.66106446	0.306984422	0.976875816	0.347270934	0.320125191	0.376748117	0.361889478	0.2629925	0.906142912	0.476203823	0.334632656	0.866383359	0.678267808
0.28413756	0.962792481	0.369938345	0.644135249	0.871740096	0.073168107	0.748427836	0.842006898	0.333896047	0.570004687	0.059423536	0.983487699	0.985063685	0.819855032	0.27904338	0.049658123	0.147059066	0.644958014	0.276286592	0.974879436	0.337458282	0.338112672	0.355401761	0.325726204	0.236698971	0.915528502	0.520078206	0.375344934	0.879733419	0.710362056
0.25572426	0.965843948	0.38294451	0.629721724	0.884526789	0.09941605	0.773585051	0.857805954	0.300506467	0.520700988	0.056391702	0.982357556	0.986557312	0.837205832	0.251141296	0.044706491	0.13235316	0.630462213	0.248658389	0.971607161	0.330741242	0.354301405	0.33854687	0.293189173	0.21303491	0.923975587	0.563907843	0.418802825	0.891749512	0.739284942
0.230152186	0.968590268	0.394650059	0.616749551	0.896021906	0.136615437	0.796226545	0.87202502	0.270455841	0.474719965	0.054835845	0.98084653	0.987901577	0.852394779	0.226030858	0.040249623	0.119117844	0.617415992	0.223792902	0.96694025	0.326692949	0.368871265	0.325715316	0.263918005	0.191737449	0.931577998	0.605375076	0.462791839	0.902564852	0.765335246
0.207137247	0.971061956	0.405185053	0.605074596	0.90635231	0.182749508	0.816603889	0.884822078	0.243410278	0.432163969	0.054867549	0.979054807	0.989111417	0.865454368	0.203433617	0.036238432	0.107206059	0.605674393	0.201413892	0.960799828	0.324919514	0.381984138	0.316448608	0.237588408	0.172570023	0.938420184	0.64367015	0.505833472	0.912299368	0.788790337
0.186423753	0.973286476	0.414666548	0.594567137	0.915632244	0.234683241	0.8349435	0.896339315	0.219069275	0.392993965	0.056577741	0.9770969	0.990200273	0.876378509	0.183099201	0.032628743	0.096485453	0.595106953	0.181272733	0.953155373	0.325061939	0.393785724	0.310304889	0.213908481	0.155319739	0.944578159	0.678629668	0.547019749	0.921061028	0.809904894
0.167781573	0.975288543	0.423199893	0.585110423	0.923964681	0.289315285	0.851449149	0.906704699	0.197162378	0.357085936	0.060022822	0.975089044	0.991180244	0.885135334	0.164802516	0.029380823	0.086836908	0.585596258	0.163145655	0.944027822	0.326796698	0.404407152	0.306865129	0.192615382	0.139795017	0.950120341	0.710356899	0.585842312	0.928947023	0.82891061
0.151003587	0.977090404	0.430879904	0.576599381	0.931442519	0.344196606	0.866304233	0.916033401	0.177446181	0.324267612	0.065215036	0.973138235	0.992062218	0.891683175	0.148341216	0.026458969	0.078153217	0.577036632	0.146831261	0.933487437	0.329835222	0.413966437	0.305737994	0.17347235	0.125823461	0.955108306	0.739059319	0.622057903	0.936044845	0.846017192
0.135903384	0.978712078	0.437791914	0.568939443	0.938149645	0.397644297	0.879673809	0.92442908	0.159701618	0.294342117	0.072118169	0.971334419	0.992855995	0.895987659	0.133533405	0.023831136	0.070337895	0.569332969	0.13214829	0.921647434	0.333922531	0.422569793	0.306563171	0.156266027	0.113249943	0.959597474	0.764978391	0.655593259	0.942433249	0.86141394
0.122313191	0.980171585	0.444012722	0.562045498	0.944161876	0.448616826	0.891706428	0.931985029	0.143731533	0.267103025	0.080648615	0.969746238	0.993570395	0.89803743	0.120215551	0.021468605	0.063304106	0.562399672	0.118933606	0.908654849	0.338835272	0.430312814	0.309013203	0.140804077	0.101934886	0.963637727	0.788358799	0.686481103	0.948183124	0.875271507
0.110082013	0.981485142	0.44961145	0.555840949	0.949547778	0.496537554	0.902535785	0.938785213	0.129358485	0.242343839	0.090680919	0.968420001	0.994213355	0.897856248	0.108240588	0.019345701	0.056973695	0.556159705	0.107040387	0.894680166	0.344379372	0.437281532	0.312794014	0.126913059	0.091752714	0.967273954	0.809435064	0.714818052	0.953358281	0.887743625
0.099073953	0.982667342	0.454650305	0.550256854	0.954369399	0.541142511	0.912282206	0.944905206	0.11642278	0.219863831	0.10205636	0.967381065	0.994792018	0.895509982	0.097476203	0.017439535	0.051276326	0.550543734	0.09633649	0.879907049	0.350387476	0.443553379	0.317644365	0.114436526	0.082590457	0.970546558	0.828426043	0.740737246	0.958016156	0.898968729
0.089166705	0.983731323	0.459185275	0.545231168	0.958682902	0.582368646	0.921053985	0.950413024	0.104780694	0.1994715	0.114593016	0.966636771	0.995312816	0.891108063	0.087803287	0.015729798	0.046148693	0.545489361	0.086702988	0.86452311	0.356716298	0.449198041	0.323334526	0.103233332	0.074346496	0.973491903	0.845533112	0.764390667	0.962208446	0.909071455
0.080250191	0.984688906	0.463266747	0.540708051	0.962539136	0.620277447	0.928948586	0.955369884	0.094302877	0.180986489	0.128095932	0.966180096	0.995781534	0.884799987	0.079114546	0.014198575	0.041533824	0.540940425	0.078032845	0.848712241	0.363244	0.454278237	0.329664387	0.093176124	0.06692944	0.976142712	0.860940095	0.785937799	0.965981684	0.918163999
0.072225344	0.98555073	0.466940072	0.536637246	0.965984133	0.655004481	0.936053727	0.959830884	0.084872916	0.16424049	0.142366378	0.965993436	0.99620338	0.876768141	0.071313254	0.012830195	0.037380442	0.536846382	0.070229733	0.832648739	0.369867638	0.458850413	0.336461229	0.084149992	0.060257102	0.978528441	0.874813997	0.805538423	0.969377752	0.926347353
0.065003004	0.986326372	0.470246065	0.532973522	0.969059554	0.686726647	0.942448354	0.963845614	0.076386038	0.149077488	0.157209592	0.966052101	0.996583041	0.867218515	0.064312147	0.011611111	0.033642397	0.533161744	0.063206954	0.816493162	0.376500747	0.462965372	0.343577312	0.076051257	0.054255588	0.980675597	0.887306098	0.823348135	0.97243435	0.933712418
0.058502928	0.98702445	0.473221459	0.52967617	0.97180309	0.715641138	0.948203518	0.967458705	0.068747948	0.135353596	0.172440766	0.966327293	0.996924737	0.856370784	0.05803244	0.010529798	0.030278158	0.52984557	0.056886483	0.800389719	0.383071066	0.466668835	0.350887421	0.068786389	0.048858467	0.982608037	0.898553174	0.839515646	0.975185407	0.94034101
0.052652899	0.98765272	0.475899313	0.526708553	0.974248821	0.741952071	0.953383166	0.970710327	0.061873782	0.122936624	0.18788927	0.966788485	0.997232263	0.844448926	0.052402952	0.009576664	0.027250342	0.526861013	0.051198098	0.784464952	0.389518433	0.470001951	0.358286443	0.062271034	0.044006025	0.984347234	0.908678735	0.854181265	0.977661465	0.946306769
0.047387924	0.988218163	0.478309381	0.524037697	0.976427539	0.765862091	0.958044849	0.973636633	0.05568716	0.111705495	0.203401323	0.967405212	0.997509036	0.831673136	0.047359339	0.008743982	0.024525308	0.524174911	0.046078604	0.768827409	0.395792843	0.473001756	0.36568706	0.056429135	0.039644591	0.98591251	0.917794215	0.867476147	0.979890009	0.951675972
0.042649514	0.988727061	0.480478443	0.521633928	0.978367044	0.787567247	0.962240364	0.976270163	0.050119338	0.101549575	0.218841341	0.96814833	0.997758132	0.81825342	0.042843414	0.008025809	0.022072777	0.52175742	0.041471126	0.753568059	0.401852676	0.475701581	0.373017576	0.051192138	0.035725928	0.987321259	0.926000097	0.87952206	0.981895782	0.956508269
0.03838503	0.98918507	0.482430599	0.519470535	0.980092418	0.807253972	0.966016327	0.978640201	0.045108447	0.092367965	0.234092265	0.968990832	0.997982319	0.80438494	0.038802542	0.007417911	0.019865499	0.519581678	0.03732448	0.738761222	0.407663098	0.478131423	0.38021992	0.046498282	0.032206676	0.988589133	0.933386945	0.89043147	0.98370105	0.96085735
0.034547102	0.989597278	0.484187539	0.517523481	0.981626262	0.825097456	0.969414694	0.980773105	0.040598802	0.084068786	0.249055129	0.969908324	0.998184086	0.790244986	0.035189108	0.006917659	0.017878949	0.51762351	0.033592608	0.724465827	0.41319462	0.48031828	0.387247822	0.042291944	0.029047858	0.98973022	0.940036365	0.900307841	0.985325857	0.964771532
0.031093103	0.989968265	0.485768785	0.515771133	0.982988929	0.84126093	0.972473224	0.982692597	0.036540286	0.07656848	0.263648103	0.970879227	0.998365678	0.775991343	0.031960039	0.006523908	0.016091054	0.515861159	0.030234058	0.710726853	0.418421836	0.482286452	0.394065171	0.038523057	0.026214419	0.990757198	0.946021868	0.909246062	0.98678824	0.968294303
0.027984674	0.990302153	0.487191907	0.51419402	0.984198729	0.855895518	0.975225902	0.984420026	0.032887789	0.069791137	0.277805198	0.971884804	0.998529109	0.761761775	0.029076381	0.006236846	0.014481949	0.514275043	0.027211533	0.697576854	0.423322318	0.484057807	0.400644548	0.035146573	0.023674823	0.991681478	0.951409666	0.917332937	0.988104437	0.971464804
0.025187296	0.990602653	0.488472716	0.512774618	0.985272116	0.869140478	0.977703311	0.985974605	0.029600714	0.063667853	0.291474783	0.972909051	0.998676198	0.747674346	0.026502919	0.006057806	0.013033754	0.512847539	0.02449147	0.68503748	0.427875701	0.485652026	0.40696592	0.032121981	0.021400678	0.99251333	0.956259387	0.924647721	0.98928906	0.97431826
0.022669914	0.990873103	0.489625444	0.511497156	0.986223864	0.881123658	0.97993298	0.987373629	0.026642519	0.05813613	0.304618033	0.973938519	0.998808578	0.73382834	0.02420783	0.005989041	0.011730379	0.511562785	0.02204367	0.673120949	0.432062927	0.487086824	0.413015494	0.029412868	0.019366404	0.993261997	0.960624726	0.931262658	0.990355261	0.976886375
0.02040458	0.991116507	0.4906629	0.51034744	0.987067224	0.891962099	0.981939682	0.988632658	0.023980315	0.053139317	0.317207368	0.974962077	0.99892772	0.720305569	0.022162376	0.006033471	0.010557341	0.510406507	0.019840961	0.661831429	0.43586569	0.488378141	0.418784708	0.026986519	0.01754893	0.993935798	0.964554029	0.937243512	0.991314879	0.979197683
0.018366153	0.991335571	0.49159661	0.509312696	0.987814075	0.901762705	0.983745713	0.989765701	0.021584502	0.048626088	0.329224965	0.975970672	0.999034948	0.707171907	0.020340623	0.006194402	0.009501607	0.509365856	0.017858895	0.651166313	0.439266041	0.489540327	0.424269351	0.024813552	0.015927427	0.994542218	0.968090826	0.942650085	0.992178567	0.981277862
0.01653201	0.991532729	0.492436949	0.508381427	0.988475051	0.91062294	0.985371142	0.990785363	0.019428437	0.044549963	0.340661347	0.976957075	0.999131453	0.694478932	0.018719182	0.006475234	0.008551446	0.50842927	0.016075478	0.641117377	0.442246191	0.490586294	0.4294688	0.022867597	0.014483065	0.995087996	0.971274305	0.947536706	0.992955916	0.983150027
0.0148818	0.991710171	0.493193254	0.507543284	0.989059665	0.918631532	0.986834027	0.991702987	0.017488141	0.040868868	0.351514095	0.977915641	0.999218307	0.682265573	0.017276977	0.006879154	0.007696301	0.507586343	0.014470922	0.631671817	0.444788472	0.491527665	0.43438536	0.021124989	0.013198798	0.995579196	0.974139748	0.951952697	0.993655556	0.984834977
0.013397213	0.991869869	0.493873929	0.506788956	0.989576424	0.925869158	0.988150624	0.992528785	0.015742031	0.03754473	0.361786681	0.978842087	0.999296476	0.670559719	0.015995034	0.007408856	0.006926671	0.506827709	0.013027422	0.622813168	0.446875463	0.492374899	0.439023698	0.019564504	0.012059179	0.996021277	0.976718917	0.955942802	0.994285255	0.986351434
0.012061774	0.992013597	0.494486536	0.50611006	0.990032924	0.932409099	0.989335562	0.993271943	0.014170684	0.034543104	0.371487418	0.979733281	0.999366828	0.659379731	0.014856283	0.008066271	0.006234004	0.506144938	0.011728962	0.614522106	0.448490252	0.493137409	0.443390352	0.01816711	0.011050186	0.996419149	0.979040403	0.959547594	0.994852006	0.987716247
0.010860661	0.992142952	0.495037882	0.505499054	0.990435944	0.938317862	0.990402005	0.993940731	0.012756616	0.031832839	0.380628543	0.980587066	0.999430145	0.648735847	0.01384538	0.008852338	0.005610604	0.505530444	0.01056113	0.60677715	0.449616816	0.493823668	0.447493321	0.01691575	0.010159079	0.996777234	0.981129944	0.962803842	0.9953621	0.988944581
0.009780535	0.992259372	0.495534094	0.504949149	0.990791531	0.943655764	0.991361804	0.994542591	0.011484092	0.029385766	0.389225403	0.98140209	0.999487131	0.63863145	0.012948546	0.009766824	0.005049543	0.5049774	0.009510958	0.599555261	0.450240491	0.494441301	0.451341706	0.01579514	0.009374269	0.997099511	0.983010711	0.965744859	0.995821202	0.990050082
0.008809395	0.99236415	0.495980685	0.504454234	0.991105075	0.948477476	0.992225624	0.99508422	0.01033895	0.027176418	0.397295754	0.982177671	0.999538417	0.629064221	0.012153416	0.010808194	0.004544589	0.50447966	0.008566775	0.592832356	0.450348499	0.494997171	0.454945417	0.014791585	0.008685204	0.99738956	0.984703558	0.968400817	0.996234408	0.991045034
0.007936435	0.99245845	0.496382616	0.50400881	0.991381374	0.952832526	0.993003061	0.995571645	0.009308446	0.025181779	0.40485916	0.982913668	0.999584575	0.620027154	0.011448906	0.011973539	0.00409013	0.504031694	0.007718077	0.58658374	0.449930497	0.495497454	0.458314924	0.013892823	0.00808227	0.997650604	0.986227259	0.970799032	0.996606307	0.991940492
0.007151929	0.992543319	0.496744355	0.503607929	0.9916247	0.95676576	0.993702755	0.99601029	0.008381107	0.023381045	0.411936475	0.983610381	0.999626118	0.611509445	0.010825085	0.013258559	0.003681117	0.503628525	0.006955407	0.58078447	0.448979125	0.495947708	0.461461041	0.013087873	0.007556707	0.997885543	0.987598713	0.972964231	0.996941029	0.992746406
0.006447119	0.992619702	0.497069919	0.503247136	0.991838852	0.960317774	0.994332479	0.996405038	0.007546611	0.021755418	0.418549405	0.984268455	0.999663506	0.603497283	0.010273064	0.01465761	0.003313005	0.503265672	0.00627025	0.575409655	0.447490507	0.496352938	0.464394762	0.012366902	0.007100526	0.998096989	0.988833131	0.974918794	0.997242289	0.993471728
0.005814116	0.992688447	0.497362927	0.502922423	0.992027207	0.963525302	0.994899231	0.99676028	0.006795665	0.020287912	0.424720143	0.984888811	0.999697155	0.595974516	0.009784892	0.016163788	0.002981705	0.502939105	0.005654934	0.570434699	0.445464689	0.496717644	0.46712711	0.011721109	0.006706449	0.99828729	0.989944203	0.97668297	0.997513433	0.994124519
0.005245812	0.992750317	0.497626634	0.502630181	0.992192766	0.966421575	0.995409308	0.997079969	0.006119908	0.018963184	0.430471064	0.985472574	0.999727439	0.588923234	0.009353464	0.017769058	0.002683534	0.502645194	0.005102548	0.565835502	0.442905983	0.497045879	0.469669028	0.011142619	0.006367843	0.998458561	0.990944255	0.978275081	0.997757472	0.994712032
0.0047358	0.992806	0.497863971	0.502367162	0.992338191	0.969036648	0.995868377	0.997367665	0.005511813	0.017767371	0.435824472	0.986021025	0.999754695	0.582324266	0.008972434	0.019464419	0.002415181	0.502380675	0.004606862	0.561588615	0.439823196	0.497341292	0.472031282	0.01062438	0.006078671	0.998612705	0.99184438	0.9797117	0.997977114	0.995240794];

d3=[0.706046088	0.031832846	0.276922985	0.046171391	0.097131781	0.823457828	0.694828623	0.31709948	0.950222049	0.034446081	0.43874436	0.381558457	0.765516788	0.795199901	0.186872605	0.489764396	0.445586201	0.64631301	0.709364831	0.754686682	0.276025077	0.679702677	0.655098004	0.162611735	0.118997682	0.498364052	0.959743959	0.340385727	0.585267751	0.223811939
0.63544214	0.127980277	0.299230686	0.091554252	0.187418025	0.74112298	0.721601277	0.356963535	0.955197695	0.043475507	0.433433808	0.443259944	0.788789339	0.815679846	0.168660528	0.540503015	0.401027581	0.631681709	0.638429008	0.765849094	0.24842814	0.661732409	0.590735909	0.194130103	0.107150662	0.548527204	0.869024508	0.40248677	0.626060727	0.30143069
0.571898411	0.214512964	0.319307618	0.132398826	0.268675051	0.667055546	0.748710756	0.407456275	0.959631432	0.048960129	0.42842714	0.498662751	0.809831135	0.834111802	0.152228811	0.585677964	0.360924823	0.618513538	0.574586593	0.773641904	0.223587346	0.645559168	0.533442879	0.210446985	0.096482775	0.593674262	0.791078339	0.45898578	0.663041626	0.371287402
0.514708938	0.292392382	0.337376856	0.169158944	0.341805333	0.600509701	0.773675574	0.460099264	0.962933744	0.051740811	0.424789299	0.548316524	0.828819131	0.850700566	0.13741718	0.62521451	0.324832341	0.606662184	0.517128302	0.778365231	0.201229429	0.631003251	0.482734452	0.215615733	0.086878142	0.634306718	0.728455635	0.510302422	0.696474097	0.43415796
0.463238332	0.362483859	0.35363917	0.202243049	0.407620881	0.540958296	0.796265374	0.510806805	0.958454177	0.05265063	0.422506507	0.592690457	0.845927135	0.865630456	0.12407548	0.658572456	0.292349107	0.595995966	0.465415759	0.780334041	0.181106858	0.617902926	0.438199725	0.213246246	0.078231959	0.67087598	0.685488678	0.556851998	0.726651107	0.490740367
0.416914728	0.425566188	0.368275253	0.232018744	0.466852236	0.4882485	0.816626168	0.558005051	0.917112926	0.052299753	0.421395174	0.632186808	0.861330764	0.879067353	0.112064341	0.684751154	0.263114196	0.586396369	0.418874413	0.779870174	0.162996362	0.606112634	0.399480198	0.206108978	0.070449583	0.703788343	0.665558447	0.599034718	0.753864127	0.541662907
0.375223443	0.482340284	0.381447728	0.25881687	0.520156593	0.442851708	0.834959302	0.601248369	0.839304061	0.051115306	0.421260413	0.667160302	0.875196265	0.891160512	0.101255704	0.702548725	0.236802776	0.577756732	0.376987159	0.777293961	0.146696839	0.59550137	0.366248265	0.196159743	0.063445635	0.733409485	0.666654166	0.63722961	0.778389993	0.587492
0.337701255	0.533436971	0.393302955	0.282935183	0.568125126	0.406121086	0.851461783	0.640561839	0.758016353	0.049394625	0.421925356	0.69794164	0.887676039	0.90204412	0.091532652	0.711070285	0.213122499	0.569981059	0.3392886	0.772916592	0.132027234	0.585951233	0.338187784	0.184716075	0.057143151	0.760068521	0.681812328	0.671791408	0.800485747	0.62873826
0.303931263	0.579423989	0.40397266	0.304641665	0.611289609	0.380263001	0.866314949	0.676158163	0.682779924	0.047345078	0.423235529	0.724860811	0.898908162	0.911838555	0.082788862	0.710224219	0.191810249	0.562982953	0.305359873	0.767033822	0.118824577	0.57735611	0.314978881	0.172641176	0.051472798	0.784061658	0.703937686	0.703049334	0.820387186	0.665860817
0.273538251	0.620812305	0.413575394	0.324177498	0.650128405	0.367613327	0.879683158	0.708316956	0.614651294	0.045111575	0.425057888	0.74826477	0.909017212	0.920651134	0.074927894	0.700873122	0.172629224	0.556684658	0.274824	0.75992127	0.106942187	0.569620499	0.296288325	0.16048912	0.046372142	0.805655485	0.728392562	0.731307074	0.838309141	0.699272139
0.246184527	0.658061789	0.422217854	0.341759748	0.685071875	0.369295513	0.891714698	0.737332656	0.553236177	0.042795336	0.427278719	0.76852518	0.91811542	0.928576115	0.067862422	0.684575944	0.155366302	0.551016192	0.247341701	0.7518313	0.09624805	0.562658449	0.281765738	0.148607843	0.041784988	0.825089931	0.752748718	0.756843497	0.854446535	0.729343127
0.221566163	0.691586325	0.429996069	0.357583774	0.716507261	0.384272773	0.902543152	0.76349198	0.497933842	0.040466761	0.429801397	0.786034919	0.926303839	0.935693622	0.061513467	0.663154406	0.139829671	0.545914573	0.22260762	0.742991327	0.086623358	0.556392604	0.271044949	0.137208911	0.037660764	0.842580934	0.775889268	0.779913802	0.868975786	0.756407566
0.199409627	0.721758407	0.436996462	0.371825396	0.744783091	0.409691274	0.912288795	0.787064489	0.448151745	0.038174333	0.432544275	0.80119547	0.933673432	0.942067243	0.055809663	0.638334851	0.125846704	0.541323116	0.200346938	0.733603314	0.077961196	0.550753344	0.263749107	0.1264139	0.033953976	0.858322838	0.797366824	0.800750907	0.882056298	0.780765927
0.179468737	0.748913282	0.443296816	0.384642857	0.770213138	0.442059519	0.92105989	0.808299141	0.40334376	0.035950849	0.435438761	0.814399504	0.940306074	0.947740284	0.05068657	0.611558467	0.113262034	0.537190804	0.180312317	0.723844185	0.070165362	0.545678009	0.259497986	0.116285115	0.030623699	0.872490552	0.817056302	0.81956696	0.89383195	0.802688695
0.161521931	0.773352668	0.448967134	0.396178571	0.793079978	0.478240021	0.928953885	0.82742364	0.363014653	0.033817819	0.438427593	0.826013333	0.946275457	0.952731061	0.046086033	0.58393037	0.101935831	0.533471724	0.162281153	0.71386691	0.063149313	0.541110208	0.257915973	0.106845951	0.027633121	0.885241495	0.834983087	0.836554868	0.904432509	0.82241935
0.1453698	0.795348116	0.454070421	0.406560714	0.813638178	0.515856331	0.936058487	0.844645078	0.326717464	0.031788616	0.441463313	0.836362823	0.951647905	0.957028121	0.041955594	0.556245761	0.091742247	0.530124551	0.1460531	0.703802044	0.056835229	0.536999188	0.258639617	0.098094489	0.024949127	0.896717344	0.851239954	0.851889816	0.913974956	0.840177051
0.130832878	0.81514402	0.458663379	0.415904642	0.832117139	0.553288922	0.942452631	0.860151158	0.294049446	0.029870742	0.444506916	0.845724632	0.95648311	0.960586714	0.038247953	0.529045863	0.082568023	0.527112096	0.131447848	0.693759538	0.051153181	0.533299269	0.261323992	0.090012609	0.022541923	0.907045608	0.865946856	0.86573072	0.92256471	0.856159061
0.117749646	0.832960333	0.462797041	0.424314178	0.848723648	0.589514853	0.948207363	0.874111642	0.26464792	0.028067474	0.447526655	0.854323052	0.960834795	0.963328002	0.034920477	0.502677812	0.07431122	0.524400887	0.118303118	0.683830684	0.046040402	0.529969342	0.265647517	0.082572143	0.020384697	0.916341046	0.879231375	0.878221616	0.930296738	0.870542927
0.105974734	0.848995014	0.466517337	0.43188276	0.863644152	0.623933627	0.953386623	0.886679854	0.238186371	0.026379072	0.450497007	0.862331643	0.964751313	0.965142308	0.031934752	0.477347576	0.066880098	0.521960798	0.106472859	0.674090088	0.041440665	0.526972408	0.271315162	0.075739041	0.018453304	0.924706941	0.891219238	0.889492956	0.937256585	0.883488447
0.095377312	0.863426228	0.469865603	0.438694484	0.877046781	0.656227693	0.958047958	0.897994142	0.214370887	0.024803662	0.453397751	0.869878303	0.96827618	0.965897032	0.029256177	0.453162667	0.060192089	0.519764718	0.095825625	0.664597602	0.03730374	0.524275167	0.278060183	0.069476187	0.016725992	0.932236246	0.902029859	0.899662819	0.943521288	0.895139446
0.085839632	0.87641432	0.472879043	0.444825036	0.889083173	0.686262963	0.96224316	0.908179258	0.192936913	0.023337894	0.456213178	0.877052327	0.97144856	0.965448906	0.026853592	0.430164777	0.05417288	0.517788246	0.086243114	0.65540016	0.033584949	0.52184765	0.285644599	0.063745309	0.015183149	0.93901262	0.911774405	0.908838031	0.94916022	0.905625368
0.07725572	0.888103603	0.475591139	0.450342532	0.899890087	0.714021488	0.966018842	0.917347647	0.173646334	0.021977425	0.458931399	0.883912187	0.974303703	0.963659186	0.024698948	0.408353722	0.048755592	0.516009422	0.077618854	0.646533488	0.030244801	0.519662885	0.293858691	0.05850825	0.013807072	0.945111358	0.920555182	0.917115198	0.954235844	0.915062717
0.069530201	0.898623957	0.478032025	0.455308279	0.909590864	0.739556989	0.969416956	0.925600627	0.156284837	0.020717276	0.461543739	0.890493098	0.976873332	0.96040958	0.022766999	0.387704315	0.043880033	0.514408479	0.069857021	0.638023677	0.027248697	0.517696597	0.302519772	0.053727811	0.012581769	0.950600221	0.92846567	0.924581647	0.9588044	0.923556344
0.062577236	0.908092277	0.480228822	0.459777451	0.918296732	0.762965809	0.97247526	0.933029468	0.140659529	0.019552101	0.46404422	0.896813746	0.979185998	0.955616412	0.021035029	0.368177768	0.039492029	0.512967632	0.062871374	0.6298886	0.024566708	0.515926937	0.311470481	0.049368283	0.011492778	0.955540199	0.935590901	0.931316302	0.96291652	0.93120062
0.056319572	0.916613764	0.48220594	0.463799706	0.926107975	0.784368021	0.975227733	0.939716373	0.126596803	0.018476378	0.466429111	0.902881896	0.981267397	0.949240872	0.019482605	0.349729017	0.035542826	0.511670868	0.056584296	0.622139192	0.022173391	0.514334243	0.320576773	0.04539578	0.010526998	0.959986178	0.942007997	0.937390466	0.966617787	0.938080478
0.05068768	0.924283102	0.483985346	0.467419735	0.933114994	0.80389521	0.977704959	0.945735372	0.113940409	0.017484555	0.468696541	0.908698782	0.983140657	0.941294072	0.018091351	0.332311127	0.031988544	0.510503782	0.050925932	0.614780576	0.020047652	0.512900819	0.329725766	0.041778408	0.009672552	0.96398756	0.947786763	0.942868546	0.969949235	0.944272357
0.045618986	0.931185507	0.485586811	0.470677762	0.939399259	0.821682614	0.979934462	0.951153125	0.10254972	0.016571148	0.470846165	0.914262365	0.98482659	0.931836696	0.016844743	0.315877706	0.028789689	0.509453403	0.045833413	0.607813061	0.01817261	0.511610737	0.338823556	0.038486349	0.008918658	0.967588804	0.952990297	0.947808711	0.972947804	0.949845054
0.041057173	0.937397671	0.48702813	0.473609986	0.945034169	0.83786413	0.981941015	0.956029652	0.092298168	0.015730821	0.472878876	0.919569612	0.986343931	0.920973983	0.015727928	0.300384038	0.02591072	0.508508063	0.041250157	0.601233011	0.016535459	0.510449663	0.347793083	0.035491866	0.008255513	0.970829923	0.957675575	0.952263484	0.975646746	0.954860487
0.036951555	0.942988619	0.488325317	0.476248987	0.950085832	0.85256922	0.983746913	0.960418992	0.083071841	0.014958431	0.474796567	0.924617978	0.987709537	0.908847419	0.014727557	0.285787446	0.023319648	0.507657257	0.037125241	0.595033606	0.015127288	0.509404697	0.356572093	0.03276926	0.007674202	0.97374693	0.961894008	0.956280289	0.978075994	0.959374381
0.03325652	0.948020472	0.489492785	0.478624088	0.954613769	0.865921064	0.985372221	0.964369792	0.074768218	0.014249063	0.47660192	0.929406278	0.988938583	0.895624691	0.013831636	0.272047241	0.020987684	0.506891531	0.033412837	0.589205494	0.013942846	0.508464227	0.365111249	0.0302948	0.007166601	0.976372237	0.965691966	0.959901935	0.980262492	0.963436888
0.029931014	0.95254914	0.490543507	0.48076168	0.958671549	0.878035547	0.986834999	0.967925852	0.067295028	0.01359805	0.478298228	0.933935126	0.990044724	0.881489338	0.01302939	0.259124486	0.018888915	0.506202378	0.0300717	0.583737351	0.012980229	0.507617805	0.373372378	0.028046627	0.00672531	0.978735013	0.96911125	0.963167065	0.982230493	0.967093148
0.026938094	0.956624941	0.491489156	0.482685512	0.962307373	0.889020801	0.988151498	0.971126597	0.060569226	0.013000986	0.479889249	0.938207052	0.991040251	0.866631173	0.01231114	0.246981709	0.017000024	0.50558214	0.027064711	0.578616363	0.012240473	0.506856024	0.381326902	0.026004658	0.00634358	0.980861511	0.972189536	0.966110559	0.984001828	0.970383785
0.024244511	0.960293162	0.492340241	0.48441696	0.965564591	0.898977099	0.989336348	0.974007519	0.054516073	0.012453728	0.481379079	0.942226439	0.991936226	0.851238154	0.011668197	0.235582648	0.015300021	0.505023926	0.024358466	0.573828631	0.011727061	0.506170422	0.388954412	0.024150468	0.006015257	0.98277536	0.974960769	0.968763896	0.985596148	0.97334536
0.021820344	0.96359456	0.493106217	0.485975264	0.968482182	0.907996993	0.990402713	0.976600567	0.049068302	0.011952394	0.482772047	0.945999329	0.992742603	0.835490001	0.011092756	0.224892049	0.013770019	0.504521534	0.021922904	0.569359512	0.011445336	0.50555338	0.39624141	0.022467184	0.005734725	0.984497823	0.977455533	0.971155487	0.98703114	0.976010779
0.019638671	0.966565819	0.493795595	0.487377738	0.971095177	0.916165595	0.991362441	0.978934501	0.044165371	0.01149336	0.484072628	0.949533171	0.993468342	0.819553593	0.010577814	0.214875536	0.012393017	0.50406938	0.019730974	0.565193909	0.011401845	0.504998042	0.403180193	0.020939373	0.005496869	0.986048041	0.979701375	0.97331097	0.988322725	0.978409659
0.017675262	0.969239952	0.494416035	0.488639964	0.973435054	0.92356095	0.992226197	0.981035207	0.039752796	0.011073249	0.485285371	0.952836552	0.994121508	0.803579973	0.010117084	0.20549954	0.011153716	0.503662442	0.017758335	0.561316509	0.011603644	0.504498237	0.409767879	0.019552934	0.005297024	0.987443236	0.981723105	0.975253482	0.989485233	0.980568651
0.015908318	0.971646672	0.494974432	0.489775968	0.975530088	0.930254457	0.993003577	0.982925989	0.035781536	0.010688923	0.486414837	0.95591892	0.994709357	0.787702726	0.009704926	0.196731278	0.010038344	0.503296198	0.015983084	0.557711974	0.012057585	0.504048414	0.416005549	0.018294997	0.005130945	0.988698913	0.983543068	0.977003902	0.990531563	0.982511746
0.014318225	0.97381272	0.495476989	0.490798371	0.977405666	0.936311309	0.993703219	0.98462782	0.032207459	0.010337471	0.487465555	0.958790341	0.995238421	0.772037432	0.009336278	0.188538769	0.00903451	0.502966578	0.014385515	0.554365105	0.012769629	0.503643572	0.421897514	0.017153827	0.004994769	0.989829021	0.985181385	0.978581068	0.991473324	0.984260532
0.012887337	0.975762163	0.49592929	0.491718534	0.979084582	0.941790947	0.994332896	0.986159581	0.028990843	0.010016197	0.488441981	0.961461271	0.995714578	0.756681932	0.009006601	0.180890872	0.008131059	0.50266992	0.012947898	0.55126097	0.013744223	0.503279215	0.42745067	0.016118725	0.004884989	0.990846119	0.986656173	0.980001982	0.992320965	0.985834441
0.01159978	0.977516661	0.496336361	0.49254668	0.980587288	0.946747491	0.994899606	0.987538265	0.026095939	0.009722611	0.489348465	0.96394236	0.99614312	0.741717161	0.008711823	0.173757336	0.007317953	0.502402928	0.011654285	0.548385003	0.014983759	0.502951294	0.432673957	0.015179952	0.004798425	0.991761507	0.987983747	0.981281981	0.993083894	0.987250959
0.010441275	0.97909571	0.496702725	0.493292012	0.981932139	0.951230169	0.995409646	0.988779169	0.023490573	0.00945441	0.490189232	0.966244293	0.996528808	0.727208353	0.008448294	0.167108859	0.006586158	0.502162635	0.010490329	0.545723082	0.016488154	0.502656164	0.43757789	0.01432864	0.004732195	0.992585356	0.989178794	0.982434909	0.993770575	0.988525827
0.009398978	0.980516854	0.497032452	0.493962811	0.983135597	0.955283719	0.995868681	0.989896061	0.021145789	0.009209472	0.490968361	0.968377655	0.996875927	0.713206459	0.00821274	0.160917135	0.005927542	0.501946372	0.009443127	0.543261592	0.018254566	0.502390548	0.442174156	0.013556722	0.004683699	0.99332682	0.990254538	0.983473252	0.994388628	0.989673208
0.008461339	0.981795883	0.497329207	0.49456653	0.984212426	0.958948764	0.996281812	0.990901332	0.019035526	0.008985843	0.491689771	0.970352821	0.997188334	0.699749664	0.008002226	0.155154908	0.005334788	0.501751735	0.008501073	0.540987464	0.020277235	0.502151493	0.446475289	0.012856861	0.004650591	0.993994138	0.991222886	0.984408279	0.994944912	0.990705852
0.007617969	0.98294701	0.497596286	0.495109877	0.985175865	0.962262171	0.996653631	0.991806138	0.017136329	0.008781721	0.492357216	0.972179877	0.9974695	0.686864914	0.007814123	0.149796005	0.004801309	0.501576561	0.00765373	0.538888208	0.022547476	0.501936344	0.450494379	0.01222239	0.004630761	0.994594724	0.992094556	0.985250157	0.9954456	0.991635232
0.006859525	0.983983024	0.497836658	0.495598889	0.986037781	0.965257376	0.996988267	0.992620518	0.015427089	0.008595452	0.492974273	0.973868554	0.99772255	0.674569396	0.007646073	0.144815367	0.004321178	0.501418905	0.00689171	0.536951924	0.025053781	0.501742709	0.454244845	0.011647248	0.004622316	0.995135251	0.992879198	0.986008059	0.995896248	0.992471674
0.006177605	0.984915436	0.498052992	0.496039	0.986808811	0.967964692	0.99728944	0.993353509	0.013888808	0.008425515	0.493544347	0.975428185	0.997950295	0.662871937	0.007495964	0.140189064	0.00388906	0.501277015	0.006206571	0.535167319	0.027782044	0.501568438	0.457740234	0.01112593	0.004623563	0.995621726	0.993585499	0.986690262	0.996301857	0.993224473
0.00556465	0.985754608	0.498247693	0.4964351	0.987498487	0.970411587	0.997560496	0.994013244	0.012504388	0.008270511	0.494070663	0.976867673	0.998155265	0.65177429	0.007361905	0.135894307	0.003500154	0.501149313	0.00559072	0.533523701	0.030715858	0.501411595	0.460994068	0.010653436	0.004632992	0.996059553	0.994221279	0.98730423	0.996666929	0.993901992
0.005013861	0.986509862	0.498422923	0.49679159	0.98811535	0.972622942	0.997804446	0.994607044	0.01125844	0.00812916	0.494556273	0.978195472	0.998339738	0.641272307	0.007242201	0.131909442	0.003150139	0.501034382	0.005037324	0.532010977	0.033836887	0.501270435	0.464019712	0.010225226	0.004649258	0.996453598	0.994793579	0.987856701	0.996995514	0.994511759
0.00451912	0.987189591	0.498580631	0.497112431	0.988667051	0.974621291	0.998024001	0.995141499	0.010137115	0.008000285	0.495004053	0.97941958	0.998505764	0.631356986	0.007135334	0.128213943	0.002835125	0.500930944	0.004540236	0.530619638	0.037125271	0.501143392	0.466830271	0.00983718	0.004671173	0.996808238	0.995308736	0.988353752	0.997291259	0.99506055
0.004074918	0.987801346	0.498722568	0.497401188	0.989160444	0.97642703	0.998221601	0.99562254	0.009127949	0.007882807	0.495416715	0.980547535	0.998655188	0.622015398	0.007039945	0.12478839	0.002551612	0.500837849	0.004093922	0.529340752	0.040560049	0.501029052	0.46943851	0.009485557	0.004697682	0.997127414	0.995772455	0.988800863	0.997557446	0.995554462];

d4=[0.751267059	0.255095115	0.505957052	0.699076723	0.890903253	0.959291425	0.54721553	0.138624443	0.149294006	0.257508254	0.840717256	0.254282179	0.814284826	0.243524969	0.929263623	0.349983766	0.19659525	0.251083858	0.616044676	0.473288849	0.351659507	0.830828628	0.585264091	0.549723608	0.917193664	0.285839019	0.757200229	0.753729094	0.380445847	0.567821641
0.678666536	0.328916319	0.505361346	0.67916905	0.901812559	0.863366709	0.592480148	0.224761914	0.134555518	0.270168053	0.75664557	0.328567553	0.826973438	0.309545787	0.836388542	0.414985287	0.176935725	0.275975472	0.556966391	0.525950755	0.316584691	0.797745765	0.539020111	0.495634921	0.826346721	0.357255117	0.780318284	0.678371904	0.436976339	0.611038309
0.6117534	0.395355402	0.504825212	0.661252145	0.911630543	0.777048943	0.633227535	0.302285596	0.121148352	0.271549305	0.680981186	0.395256763	0.843172213	0.366862058	0.752794874	0.473485663	0.159242153	0.298377925	0.502223269	0.573332371	0.284951075	0.767971189	0.499680328	0.446963127	0.744229147	0.421529605	0.801613516	0.610596095	0.490547011	0.649933653
0.550983887	0.455150577	0.504342691	0.645126931	0.920466004	0.699416082	0.669903076	0.372056856	0.109047573	0.265272699	0.61288372	0.455059673	0.858618752	0.416199137	0.677559954	0.526127825	0.143317938	0.318540132	0.45240677	0.615945379	0.256463682	0.74117407	0.466616643	0.403145099	0.670128819	0.479376643	0.821039785	0.549746544	0.540037007	0.684939688
0.496079525	0.508966234	0.503908422	0.630614238	0.928416677	0.62971693	0.702912069	0.434850921	0.098147438	0.254204618	0.551597501	0.508621648	0.872698249	0.458274308	0.609851411	0.573451929	0.128986144	0.336686119	0.40736012	0.654236843	0.230820006	0.717056663	0.439215357	0.363689955	0.603326832	0.531438969	0.838670189	0.495407519	0.585211987	0.716445271
0.446574887	0.557400325	0.503517579	0.617552814	0.935570288	0.567468718	0.732620549	0.491365496	0.088334396	0.240402075	0.496444057	0.556537203	0.885411719	0.493786207	0.548919272	0.615754339	0.11608753	0.353017507	0.366727422	0.688589041	0.20773905	0.695350996	0.416881448	0.328160956	0.543138048	0.578295023	0.854624322	0.447579335	0.626201169	0.7448004
0.401978073	0.600991008	0.503165821	0.605797533	0.942005514	0.512645541	0.759358342	0.542228514	0.079501652	0.225259443	0.446816236	0.599359993	0.896865152	0.523409088	0.494088188	0.652546413	0.104478777	0.367715757	0.330115355	0.719318719	0.186965594	0.675815897	0.399044131	0.296166619	0.48892635	0.620465317	0.869036591	0.406942087	0.663274036	0.770320089
0.361819182	0.640222622	0.502849239	0.595217779	0.947792864	0.465948015	0.783422428	0.588005116	0.071551802	0.209688752	0.402174208	0.637608411	0.907176685	0.547787411	0.444750153	0.681063962	0.094030899	0.380944181	0.297142735	0.746677092	0.168269249	0.658234307	0.385162442	0.267355031	0.440108827	0.658418091	0.882041969	0.375083319	0.696745039	0.793287862
0.325664264	0.675531075	0.502564315	0.585696001	0.952995503	0.429006261	0.805080141	0.629203928	0.06439678	0.19427013	0.362043414	0.671767247	0.916458236	0.567530632	0.400357837	0.694240296	0.084627809	0.392849763	0.267455462	0.770852153	0.151442446	0.642410876	0.374729991	0.241409501	0.396155089	0.692574375	0.893769591	0.354350346	0.72693252	0.813958896
0.293117918	0.707308682	0.502307884	0.577126401	0.957670006	0.404150878	0.824572101	0.666282717	0.057957192	0.179361406	0.326014245	0.702286716	0.92481207	0.583208754	0.360418526	0.683578443	0.076165028	0.403564787	0.240729996	0.791974626	0.136298294	0.628169789	0.367278412	0.218044899	0.356584458	0.723312894	0.904340038	0.346958378	0.754141147	0.832562856
0.263822	0.735908529	0.502077095	0.569413761	0.961867082	0.393420475	0.842114875	0.699653475	0.052161531	0.16517336	0.293742711	0.729580426	0.932330699	0.595349085	0.324488639	0.649652922	0.068548525	0.413208308	0.21667287	0.810128278	0.12266858	0.61535281	0.362379379	0.197004458	0.320962349	0.750975259	0.913864401	0.353630689	0.778654858	0.849306442
0.23745303	0.761648391	0.501869386	0.562472385	0.965632229	0.397211105	0.857903376	0.729686994	0.046945423	0.151820125	0.264950928	0.754023596	0.939097546	0.604434385	0.292168786	0.602376573	0.061693673	0.421887477	0.195018814	0.825364343	0.11040195	0.603817529	0.359645256	0.178056937	0.28889642	0.775870441	0.922444229	0.372893473	0.800734631	0.864375687
0.213719273	0.784814267	0.501682447	0.556225147	0.969006343	0.413730765	0.872113032	0.756716994	0.042250921	0.139352635	0.239425915	0.775952338	0.945187745	0.610902364	0.263099322	0.550956693	0.055524306	0.429698729	0.175528478	0.837718728	0.099362341	0.593435776	0.358728577	0.160994076	0.260032802	0.798277056	0.930171899	0.40167723	0.820618485	0.87793802
0.192357824	0.805663555	0.501514203	0.550602632	0.972026274	0.439741906	0.884901723	0.78104382	0.038025871	0.12778082	0.217015232	0.795664289	0.950668944	0.615146368	0.236956346	0.500391862	0.049971875	0.436728856	0.157986108	0.847229836	0.089427745	0.584092198	0.359320603	0.145628313	0.234052522	0.818444904	0.937131181	0.436526297	0.838522519	0.890144131
0.173131873	0.824427914	0.501362782	0.545542369	0.974725313	0.471770707	0.896411547	0.802937787	0.034223332	0.117088378	0.197618423	0.813420515	0.955602033	0.617517003	0.21344811	0.452813553	0.044974688	0.443055971	0.142197329	0.853954525	0.080489475	0.575682979	0.361149219	0.131790731	0.210668184	0.836597712	0.943397887	0.474469667	0.854642379	0.901129639
0.155828174	0.841315838	0.501226504	0.540988132	0.977133628	0.506901735	0.90677039	0.822642183	0.030801059	0.107242652	0.181174126	0.829448355	0.960041819	0.618324448	0.192311802	0.408956656	0.040477219	0.448750374	0.127987085	0.857980039	0.072452192	0.568114681	0.363976392	0.119329208	0.189620919	0.852936428	0.949040532	0.513317302	0.869154882	0.911016604
0.140254731	0.856514969	0.501103854	0.536889319	0.979278634	0.543012097	0.916093349	0.840375965	0.02772103	0.098201246	0.167643723	0.843944853	0.96403763	0.617841232	0.173310649	0.368941035	0.036429497	0.453875336	0.115197751	0.859430608	0.065235009	0.561303213	0.367595384	0.108106751	0.17067761	0.867641969	0.954120973	0.551605466	0.882219639	0.919914878
0.1262387	0.870194187	0.500993468	0.533200387	0.981185312	0.578689995	0.924484012	0.856336197	0.02494903	0.08991648	0.156993421	0.857080396	0.967633862	0.616305258	0.156231323	0.33262668	0.032786547	0.458487803	0.103687418	0.858468482	0.058773903	0.555172891	0.371827873	0.097999993	0.153628362	0.880877333	0.958695017	0.588426417	0.893980622	0.927923329
0.113624493	0.882505483	0.500894121	0.529880348	0.982876475	0.613059667	0.932035609	0.87070024	0.022454263	0.082338367	0.149177166	0.869002319	0.970870472	0.613922934	0.140881614	0.299770497	0.029507892	0.462639022	0.093328339	0.855290137	0.053025421	0.549655602	0.376521094	0.088897846	0.138284217	0.892789361	0.962812991	0.623260276	0.904567621	0.935130939
0.102272058	0.89358565	0.500804709	0.526892313	0.984372991	0.645616758	0.938832047	0.883627719	0.020209016	0.075416601	0.144122763	0.879838251	0.973783422	0.610872279	0.127088339	0.270096079	0.026557103	0.46637512	0.084005519	0.850119038	0.047971276	0.544690042	0.381545076	0.080700279	0.12447509	0.903510291	0.966520259	0.655844661	0.914097597	0.941617792
0.092055335	0.9035578	0.500724238	0.524203082	0.985693971	0.676102933	0.944948841	0.895262296	0.018188348	0.069101858	0.141722906	0.889699124	0.976405078	0.607305928	0.114695459	0.243325075	0.023901393	0.469737608	0.07561545	0.843196528	0.043622917	0.540221038	0.386790041	0.073317219	0.112047899	0.913159185	0.969857703	0.686083052	0.922675923	0.947455962
0.08286086	0.912532735	0.500651815	0.521782774	0.98685692	0.704418411	0.950453956	0.905733268	0.016369814	0.063346632	0.141831803	0.898681787	0.978764568	0.603353971	0.103562392	0.219191168	0.021511254	0.472763847	0.068064963	0.834772297	0.040024767	0.536198934	0.392163973	0.066667565	0.100864884	0.921843221	0.972862153	0.713983186	0.930397513	0.952710318
0.074586508	0.920610176	0.500586633	0.519604496	0.987877875	0.73056334	0.95540856	0.915157005	0.014733214	0.058105741	0.144267035	0.906871225	0.98088811	0.599126596	0.093562494	0.197445943	0.019360128	0.475487463	0.061270201	0.825095543	0.037254669	0.532579041	0.397590405	0.060678294	0.090802083	0.92965887	0.97556679	0.739616505	0.937347843	0.95743924
0.067140359	0.927879873	0.50052797	0.517644047	0.988771509	0.754599222	0.959867703	0.923638237	0.013260367	0.053336618	0.148815497	0.914342424	0.982799298	0.594716514	0.084581688	0.177860884	0.017424115	0.477938716	0.055155683	0.814407496	0.035420303	0.529321137	0.403006393	0.055283661	0.081747969	0.936692965	0.978001497	0.763091707	0.943603886	0.961695272
0.060439681	0.934422601	0.500475173	0.515879642	0.989551236	0.776623729	0.963880932	0.931271223	0.011934912	0.048999441	0.155241892	0.921161899	0.984519367	0.59020117	0.076517229	0.160227499	0.015681704	0.480144845	0.049653472	0.802935636	0.034651006	0.526389023	0.408360712	0.050424471	0.073602209	0.943023657	0.980193187	0.784537584	0.949234947	0.965525702
0.054410005	0.940311056	0.500427656	0.514291678	0.990229299	0.796754329	0.967492839	0.938140797	0.010742122	0.045057158	0.163298236	0.927388961	0.98606743	0.58564473	0.069276596	0.144356555	0.014113534	0.48213036	0.044702418	0.790889636	0.035085391	0.523750121	0.41361223	0.046047429	0.066274553	0.948721284	0.982166098	0.804091937	0.954303427	0.968973091
0.048984309	0.945610665	0.50038489	0.51286251	0.990816846	0.815117683	0.970743554	0.944323306	0.009668742	0.041475444	0.172733113	0.933076742	0.987460686	0.581099859	0.062776485	0.130076923	0.01270218	0.483917324	0.04024748	0.778458867	0.036856192	0.521375109	0.418728469	0.042104553	0.05968383	0.95384915	0.983942053	0.821894482	0.958865504	0.972075742
0.044102261	0.950380313	0.500346401	0.511576259	0.99132401	0.831842824	0.973669198	0.949887465	0.008702843	0.038222612	0.183299823	0.938273042	0.988714617	0.57660931	0.056941908	0.117234259	0.011431962	0.485525592	0.036239115	0.765811228	0.04007452	0.519237598	0.423684339	0.038552645	0.05375704	0.958464232	0.985540703	0.838082371	0.962971751	0.974868129
0.03970956	0.954672997	0.500311761	0.510418633	0.991759975	0.847056837	0.976302278	0.954895117	0.007833685	0.035269491	0.194762939	0.943021015	0.989843155	0.572207318	0.051705371	0.105689681	0.010288766	0.486973033	0.032632728	0.753093017	0.044815983	0.517313838	0.428461023	0.035352814	0.048428533	0.962617806	0.986979739	0.852787452	0.966667699	0.977381278
0.035757324	0.958536412	0.500280585	0.50937677	0.992133048	0.860882181	0.97867205	0.959401919	0.007051602	0.032589286	0.206903135	0.947359743	0.990858839	0.567920843	0.047006139	0.095318477	0.009259889	0.488275729	0.029388176	0.740429572	0.051110721	0.515582454	0.433044996	0.032470044	0.043639275	0.966356024	0.988275092	0.866134657	0.969994332	0.979643113
0.032201556	0.962013486	0.500252526	0.508439093	0.992450721	0.873435118	0.980804845	0.963457964	0.006347892	0.030157436	0.219520372	0.951324704	0.991772954	0.563770647	0.042789571	0.08600889	0.0083339	0.489448156	0.026469322	0.727926444	0.058938575	0.514024209	0.437427177	0.029872812	0.039336174	0.969720421	0.989441102	0.87824117	0.972988543	0.981678765
0.029002646	0.965142852	0.500227274	0.507595184	0.992719731	0.884824858	0.98272436	0.967108333	0.005714722	0.027951459	0.232435645	0.954948174	0.992595658	0.559772245	0.039006517	0.077660986	0.00750051	0.490503341	0.023843636	0.715670907	0.068229544	0.512621788	0.441602189	0.027532737	0.035471478	0.972748378	0.99049068	0.889216082	0.975683544	0.983510853
0.02612494	0.967959282	0.500204546	0.506835665	0.992946125	0.895153197	0.984451923	0.970393599	0.005145039	0.025950807	0.245491564	0.95825956	0.993336092	0.55593673	0.035612773	0.070185597	0.006750459	0.491453007	0.021481831	0.703733655	0.078868763	0.511359609	0.445567721	0.025424268	0.032002231	0.97547354	0.991435449	0.899160377	0.978109227	0.985159732
0.02353634	0.970494069	0.500184092	0.506152099	0.993135309	0.904514465	0.986006731	0.97335028	0.004632495	0.024136719	0.25855205	0.961285689	0.994002483	0.552271489	0.032568594	0.063503348	0.006075413	0.492307706	0.019357542	0.692170564	0.090704661	0.510223648	0.449323975	0.023524398	0.028889777	0.977926185	0.992285874	0.908167131	0.980292503	0.986643724
0.02120795	0.972775377	0.500165683	0.505536889	0.993292109	0.912995682	0.987406057	0.976011238	0.004171375	0.022492083	0.271501397	0.964051056	0.994602234	0.548780827	0.029838249	0.057543739	0.005467872	0.493076935	0.017447032	0.68102444	0.103558773	0.509201283	0.452873191	0.021812414	0.026099317	0.980133567	0.993051373	0.916321839	0.982257592	0.987979317
0.019113756	0.974828554	0.500149114	0.5049832	0.99342082	0.920676846	0.988665451	0.97840605	0.003756535	0.021001306	0.284242908	0.966578042	0.99514201	0.5454665	0.027389623	0.052244285	0.004921085	0.493769242	0.01572893	0.670326702	0.11723583	0.508281155	0.456219244	0.020269667	0.023599506	0.98212021	0.993740427	0.923702825	0.984026295	0.989181352
0.017230337	0.976676413	0.500134203	0.50448488	0.993525252	0.927631294	0.989798906	0.980561336	0.003383342	0.019650186	0.296697282	0.968887108	0.995627809	0.542328178	0.025193854	0.047549702	0.004428976	0.494392318	0.014183993	0.660098949	0.131533086	0.50745304	0.459367297	0.018879365	0.021362095	0.983908189	0.994360669	0.930381685	0.985618237	0.990263183
0.015536607	0.978339487	0.500120783	0.504036392	0.993608776	0.933926107	0.990819015	0.982501052	0.003047628	0.018425798	0.308800889	0.970996964	0.996065028	0.539363841	0.023225011	0.043411132	0.003986079	0.494953086	0.012794897	0.650354413	0.146248273	0.506707736	0.462323504	0.017626388	0.019361603	0.98551737	0.99491897	0.936423753	0.987051081	0.991236831
0.014013582	0.979836253	0.500108704	0.503632753	0.99367437	0.93962253	0.991737113	0.984246759	0.002745638	0.017316388	0.320504011	0.972924721	0.996458525	0.536570119	0.021459796	0.039785392	0.003587471	0.495457777	0.011546043	0.641099265	0.161185873	0.506036962	0.465094766	0.016497121	0.017575031	0.986965633	0.995421516	0.941888561	0.988340726	0.992113115
0.01264417	0.981183343	0.500097834	0.503269477	0.993724654	0.944776399	0.992563402	0.985817861	0.002473994	0.016311266	0.33176914	0.974686034	0.996812672	0.533942575	0.019877285	0.036634268	0.003228724	0.495912	0.010423385	0.632333793	0.176161726	0.505433266	0.467688518	0.015479305	0.015981598	0.988269069	0.995873874	0.946830292	0.989501481	0.992901771
0.011412983	0.982395723	0.50008805	0.50294253	0.993761928	0.949438555	0.993307061	0.987231823	0.002229654	0.015400722	0.34256936	0.976295218	0.997131404	0.531475959	0.018458684	0.033923823	0.002905851	0.4963208	0.009414277	0.624053437	0.191006125	0.504889939	0.470112555	0.014561899	0.014562511	0.989442162	0.996281058	0.951298208	0.990546228	0.993611561
0.010306167	0.983486866	0.500079245	0.502648277	0.993788206	0.953655242	0.993976355	0.98850436	0.002009882	0.014575931	0.352886843	0.977765371	0.997418264	0.529164406	0.01718712	0.031623756	0.002615266	0.49668872	0.008507331	0.616249706	0.205565655	0.504400945	0.472374888	0.013734961	0.013300762	0.990497946	0.996647579	0.955337067	0.99148656	0.994250373
0.009311248	0.984468894	0.500071321	0.502383449	0.993805247	0.957468489	0.994578719	0.989649619	0.001812214	0.013828882	0.362711482	0.979108471	0.997676437	0.527001614	0.01604744	0.029706784	0.00235374	0.497019848	0.007692296	0.60891097	0.219704042	0.503960851	0.47448362	0.012989536	0.012180942	0.991448152	0.996977497	0.958987499	0.992332912	0.994825303
0.008416998	0.98535272	0.500064189	0.502145104	0.99381458	0.96091646	0.995120847	0.990680328	0.001634431	0.013152301	0.372039657	0.980335473	0.997908793	0.524980991	0.015026046	0.028148089	0.002118366	0.497317863	0.006959942	0.602023145	0.233302288	0.503564766	0.47644685	0.01231756	0.011189077	0.992303336	0.99727447	0.962286368	0.993094676	0.995342741
0.007613308	0.986148163	0.50005777	0.501930594	0.993817532	0.964033793	0.995608762	0.991607946	0.001474538	0.012539586	0.380873135	0.981456394	0.998117914	0.523095773	0.014110727	0.0269248	0.001906529	0.497586077	0.006301957	0.59557029	0.246258303	0.503208289	0.478272594	0.011711771	0.010312492	0.993073003	0.997541786	0.965267106	0.993780305	0.995808435
0.006891076	0.986864061	0.500051993	0.501737534	0.993815253	0.966851908	0.996047885	0.992442784	0.001330738	0.011984748	0.3892181	0.982480393	0.998306122	0.521339124	0.013290529	0.026015553	0.001715876	0.497827469	0.00571086	0.589535101	0.258486225	0.50288746	0.479968716	0.011165626	0.009539675	0.993765702	0.99778241	0.967960018	0.994397409	0.99622756
0.006242111	0.98750837	0.500046794	0.501563781	0.993808731	0.969399291	0.996443097	0.993194121	0.001201416	0.011482351	0.397084303	0.983415843	0.99847551	0.519704222	0.012555618	0.025400102	0.001544289	0.498044722	0.005179917	0.583899341	0.269915552	0.502598714	0.481542886	0.010673231	0.008860173	0.994389132	0.997999006	0.970392562	0.994952836	0.996604772
0.005659039	0.988088248	0.500042114	0.501407403	0.993798819	0.971701756	0.996798787	0.993870309	0.001085117	0.011027467	0.404484328	0.984270399	0.998627958	0.518184319	0.011897173	0.025059003	0.00138986	0.49824025	0.004703064	0.578644194	0.280490198	0.502338843	0.483002533	0.01022928	0.008264488	0.994950219	0.998193974	0.972589616	0.995452751	0.996944263
0.005135222	0.988610138	0.500037903	0.501266663	0.993786242	0.973782693	0.997118908	0.994478864	0.000980532	0.010615627	0.411432954	0.985051055	0.998765162	0.516772797	0.011307279	0.024973372	0.001250874	0.498416225	0.004274844	0.573750565	0.290167517	0.502104958	0.48435482	0.009828988	0.007743988	0.995455197	0.998369475	0.974573707	0.995902701	0.997249806
0.004664687	0.989079839	0.500034113	0.501139996	0.993771621	0.975663282	0.997407017	0.995026551	0.000886484	0.010242778	0.417946608	0.985764204	0.998888646	0.51546321	0.010778834	0.025124698	0.001125786	0.498574602	0.003890347	0.56919932	0.298917349	0.501894463	0.485606624	0.009468049	0.007290834	0.995909677	0.998527454	0.976365231	0.99630768	0.997524794];

d5=[0.07585429	0.053950119	0.530797553	0.77916723	0.934010684	0.129906208	0.568823661	0.469390641	0.01190207	0.337122644	0.162182308	0.794284541	0.311215042	0.528533136	0.165648729	0.601981941	0.262971285	0.654079098	0.689214503	0.748151593	0.450541599	0.083821378	0.228976969	0.913337362	0.152378019	0.825816977	0.538342435	0.996134717	0.078175529	0.44267827
0.068304898	0.147885822	0.527717798	0.751250507	0.940295038	0.213935357	0.611721324	0.52245156	0.010711902	0.336852926	0.147162066	0.805658708	0.380085165	0.530131281	0.149106994	0.54290269	0.236675491	0.638671189	0.620329091	0.757313024	0.405488029	0.12543924	0.212804318	0.866325837	0.137196526	0.84323528	0.484510848	0.990307938	0.170332069	0.498379334
0.061509593	0.232427954	0.524946018	0.726125456	0.945926372	0.289968499	0.650493662	0.570206374	0.009640773	0.32782049	0.13429003	0.814452747	0.442073751	0.531126496	0.134219495	0.489368305	0.213008278	0.62480407	0.558331366	0.763205602	0.364941151	0.162895316	0.200098205	0.812761669	0.123528255	0.858911752	0.436070413	0.986265794	0.253277096	0.548471676
0.055393297	0.308515874	0.522451416	0.703512911	0.95097081	0.358717962	0.685428227	0.613185687	0.008676789	0.313207481	0.123578528	0.821097487	0.497865261	0.531622849	0.120822938	0.440978774	0.191707548	0.612323663	0.502532893	0.766170109	0.328452651	0.196605785	0.190709097	0.755820442	0.111223872	0.873020577	0.392507338	0.983518551	0.327930778	0.59348042
0.049888374	0.376995001	0.520206275	0.68316162	0.955488003	0.420846781	0.716880142	0.651867041	0.007809245	0.295423822	0.115061355	0.826056937	0.548078263	0.531709774	0.108770032	0.397303278	0.172536825	0.601091297	0.45231401	0.766551649	0.295622165	0.226945206	0.184456992	0.69817242	0.100148513	0.885718519	0.353435763	0.981716547	0.39512154	0.633855785
0.044933898	0.438626216	0.518185647	0.664845458	0.959531736	0.476967421	0.745190201	0.686680221	0.00702851	0.276140173	0.108778489	0.829800072	0.593270219	0.53146392	0.097928133	0.357918291	0.155283154	0.590982167	0.40711697	0.764691327	0.266095341	0.254250685	0.181129392	0.64172479	0.090180512	0.897146667	0.318786341	0.980607324	0.455595152	0.669974285
0.040474996	0.494094309	0.516367082	0.648360912	0.963150489	0.527642548	0.770670401	0.718012031	0.006325917	0.256456112	0.104759408	0.832771883	0.633943088	0.530950781	0.088177888	0.322423727	0.139754843	0.58188395	0.366439762	0.760918754	0.239563579	0.278825617	0.180484221	0.587691893	0.081210189	0.907432	0.289381298	0.980006627	0.510022941	0.702145728
0.036462251	0.544015593	0.514730374	0.633524821	0.966387933	0.573386998	0.793603015	0.746210594	0.005693666	0.237068394	0.10300801	0.83536843	0.670548721	0.530226143	0.079411923	0.290449106	0.125779361	0.573695555	0.32983054	0.75554595	0.215765265	0.300943055	0.182256341	0.536766581	0.073138733	0.9166888	0.268234153	0.979778646	0.559009191	0.730645193
0.032851161	0.588944749	0.513257337	0.620172339	0.969283397	0.614670426	0.814242547	0.77158922	0.005124739	0.218401648	0.103491439	0.83791893	0.703493816	0.529337357	0.071533635	0.261655083	0.113201426	0.566326	0.296882621	0.748862867	0.194487889	0.32084875	0.186166102	0.489284015	0.065877157	0.92501992	0.261827724	0.97982242	0.603097829	0.755823114
0.02960165	0.629380989	0.511931603	0.608155105	0.971872271	0.651920283	0.832818207	0.794429888	0.004612817	0.20070056	0.106134161	0.840676081	0.733144415	0.528324452	0.064456075	0.235732822	0.101881284	0.5596934	0.267229964	0.741134503	0.175569961	0.338763875	0.191928448	0.445346851	0.059345351	0.932517928	0.277149598	0.980062355	0.642778438	0.778309391
0.026677636	0.665773605	0.510738443	0.597339594	0.974186391	0.685524919	0.849536338	0.814986377	0.004152215	0.184092198	0.110817521	0.843814335	0.759829961	0.527221123	0.058100937	0.212402371	0.091693156	0.55372406	0.240543119	0.732599422	0.158901298	0.354887487	0.199261474	0.4049124	0.053471215	0.939266135	0.313722761	0.980441543	0.678491679	0.798937505
0.024046626	0.698526959	0.509664598	0.587605635	0.976254379	0.715836669	0.864582677	0.833487091	0.003737813	0.168627422	0.117384047	0.84743485	0.783846956	0.526055588	0.052397641	0.191410644	0.08252384	0.548351654	0.216525561	0.723469443	0.144420241	0.369398739	0.207893679	0.367850694	0.048189871	0.945339522	0.363274629	0.980916972	0.710634179	0.818147628
0.021679365	0.728004978	0.508698139	0.578845071	0.978101954	0.743174835	0.878124392	0.850137595	0.003365004	0.154308275	0.125645145	0.851575268	0.805462255	0.524851342	0.047282514	0.172529289	0.074271457	0.543516488	0.194910406	0.71393021	0.132106769	0.382458865	0.217569594	0.333982331	0.043442945	0.95080557	0.417293849	0.981456068	0.739562919	0.835904697
0.019549512	0.754535195	0.507828325	0.570960564	0.979752216	0.767828528	0.890311941	0.865122897	0.003029637	0.141106079	0.135390602	0.856222308	0.824916025	0.523627817	0.04269806	0.155552583	0.066844311	0.53916484	0.175457449	0.70414241	0.121971231	0.394212978	0.228053717	0.303102813	0.039177918	0.955725013	0.470653133	0.982034156	0.765599203	0.852123355
0.017633349	0.778412391	0.507045492	0.563864508	0.981225901	0.790059333	0.90128074	0.878609509	0.002727976	0.128973445	0.146398473	0.861325303	0.84242442	0.522400953	0.038592312	0.140295435	0.06015988	0.535248356	0.157950492	0.694243412	0.114039476	0.40479168	0.2391329	0.27499805	0.035347537	0.960152511	0.520997357	0.982632583	0.789032214	0.866825198
0.015909523	0.799901867	0.506340943	0.557478057	0.982541616	0.81010379	0.91115266	0.890747293	0.002456656	0.117852239	0.15844425	0.866809143	0.858181975	0.521183706	0.034918263	0.126591521	0.054143892	0.53172352	0.142194952	0.68434916	0.1083361	0.414312512	0.25061741	0.249454092	0.031909282	0.96413726	0.567464503	0.98323731	0.810122231	0.880102329
0.014358807	0.819242395	0.505706849	0.551730251	0.983716049	0.828175688	0.92003739	0.901671125	0.002212647	0.107678883	0.171308636	0.87258558	0.872363776	0.519986477	0.031633356	0.11429156	0.048729503	0.528551168	0.128015693	0.674556179	0.104868156	0.422881261	0.26234096	0.226263123	0.028824878	0.967723534	0.609884465	0.983837855	0.82910351	0.892071995
0.012963891	0.83664887	0.505136164	0.546557226	0.98476416	0.844468171	0.928033649	0.9115024	0.001993218	0.098387854	0.184783614	0.878562329	0.885127397	0.518817496	0.028699048	0.103261727	0.043856553	0.525696051	0.115255088	0.664943607	0.103611663	0.430593135	0.274159964	0.205226999	0.02605986	0.970951181	0.648387022	0.984426482	0.84618689	0.902854157
0.011709191	0.852314698	0.504622547	0.541901504	0.985699357	0.85915568	0.935230281	0.92035037	0.001795912	0.089913981	0.198676761	0.884649813	0.896614656	0.517683148	0.026080414	0.093382201	0.039470897	0.523126446	0.103771269	0.655575165	0.104502701	0.437533822	0.28595225	0.186159194	0.023583182	0.973856063	0.683223048	0.984997582	0.861562131	0.912562769
0.010580677	0.866413943	0.504160293	0.537711353	0.986533649	0.872395709	0.941707251	0.92831337	0.001618514	0.082193924	0.21281399	0.890765715	0.906953189	0.516588259	0.023745803	0.08454583	0.035523808	0.520813801	0.093436547	0.646501045	0.107433888	0.443780439	0.297615448	0.168885715	0.021366853	0.976470456	0.714683966	0.985547197	0.875400022	0.921302951
0.009565715	0.879103264	0.503744263	0.533940218	0.987277791	0.884330425	0.947536525	0.935479897	0.001459029	0.07516709	0.227040935	0.89683766	0.91625787	0.515536346	0.021666534	0.076656897	0.031971427	0.518732421	0.084135998	0.637759653	0.112256033	0.449402395	0.309065181	0.153245334	0.019385624	0.978823411	0.74306544	0.986072648	0.887854275	0.929170446
0.008652935	0.890523652	0.503369837	0.530546196	0.987941411	0.895088127	0.952782871	0.941929605	0.001315661	0.068776169	0.241223289	0.902804443	0.924632082	0.514529825	0.019816621	0.069629992	0.028774284	0.516859179	0.07576619	0.62937923	0.118783932	0.454462156	0.320233202	0.139089403	0.017616693	0.98094107	0.768651222	0.986572248	0.899063237	0.936251958
0.007832099	0.900802002	0.503032853	0.527491577	0.988533122	0.904784583	0.957504583	0.94773418	0.001186794	0.062967415	0.255246338	0.908616193	0.932168873	0.5135702	0.018172532	0.063388947	0.025896856	0.515173261	0.068234028	0.621379314	0.126804842	0.45901594	0.331065536	0.126281398	0.016039457	0.982846963	0.791706379	0.987045071	0.909151421	0.942625779
0.007093991	0.910052517	0.502729568	0.524742419	0.989060631	0.913524231	0.961754124	0.952958142	0.001070969	0.057690743	0.269013956	0.914233829	0.938951985	0.512658216	0.016712969	0.057865866	0.02330717	0.513655935	0.061455727	0.613772054	0.136088128	0.463114346	0.34152071	0.114696301	0.014635275	0.984562266	0.812474992	0.987490779	0.918230889	0.948362506
0.006430315	0.91837798	0.502456611	0.522268177	0.989530831	0.921401285	0.965578711	0.95765956	0.000966876	0.052899714	0.282447233	0.919628089	0.945056786	0.511793999	0.015418671	0.053000202	0.020976453	0.512290342	0.055355877	0.606563392	0.146394823	0.466802912	0.351568081	0.104219904	0.013387266	0.98610604	0.831179975	0.987909481	0.926402503	0.953525745
0.005833602	0.925870897	0.50221095	0.520041359	0.989949884	0.928500715	0.969020839	0.961890696	0.000873335	0.048551433	0.295482912	0.924778346	0.950551107	0.510977171	0.014272231	0.048737901	0.018878808	0.511061307	0.049866609	0.599754102	0.157486209	0.47012262	0.361186304	0.094748073	0.01228013	0.987495436	0.84802392	0.98830162	0.933757036	0.958172786
0.005297132	0.932614522	0.501989855	0.518037223	0.990323297	0.934899157	0.972118754	0.965698586	0.000789281	0.044606408	0.308071738	0.929671353	0.955495996	0.51020695	0.013257936	0.045030608	0.016990927	0.509955177	0.044926838	0.593340705	0.169130903	0.473110358	0.37036194	0.086186001	0.011299987	0.988745892	0.86319039	0.988667892	0.940376188	0.962355208
0.004814853	0.938683785	0.50179087	0.516233501	0.990655993	0.940665714	0.974906878	0.969125562	0.000713758	0.041028368	0.32017681	0.934300023	0.959946396	0.509482232	0.012361614	0.041834916	0.015291834	0.508959659	0.040481588	0.587316272	0.181110284	0.475799323	0.379088204	0.078447484	0.010434232	0.989871303	0.876845376	0.989009172	0.946333489	0.966119449
0.00438132	0.944146121	0.501611783	0.514610151	0.99095237	0.9458627	0.97741619	0.972209725	0.000645905	0.037784072	0.331771986	0.938662293	0.963951756	0.508801665	0.011570501	0.03911168	0.013762651	0.508063693	0.036481382	0.581671119	0.193222317	0.47821939	0.387363857	0.071454219	0.009671415	0.990884173	0.889138789	0.989326461	0.951695116	0.96950731
0.003991633	0.949062224	0.501450604	0.513149136	0.991216354	0.950546299	0.979674571	0.974985363	0.000584948	0.034843108	0.34284039	0.942760115	0.96755658	0.508163711	0.010873106	0.036825391	0.012386386	0.507257324	0.032881688	0.57639341	0.205283954	0.480397451	0.395192229	0.065135146	0.009001128	0.991795755	0.900205895	0.989620848	0.956520632	0.972556418
0.003641379	0.953486717	0.501305544	0.511834222	0.991451455	0.954767166	0.981707113	0.977483336	0.000530189	0.032177693	0.353373034	0.946598567	0.970800922	0.507566694	0.010259105	0.034943601	0.011147747	0.506531591	0.029642429	0.57146967	0.217132385	0.482357706	0.402580363	0.05942582	0.008413907	0.99261618	0.910168672	0.989893469	0.96086364	0.97530064
0.003326591	0.95746876	0.50117499	0.5106508	0.991660802	0.958570967	0.983536401	0.97973142	0.000481	0.029762476	0.36336756	0.950185103	0.973720829	0.507008844	0.009719228	0.033436418	0.010032973	0.505878432	0.026727536	0.566885232	0.228625383	0.484121936	0.409538272	0.054267832	0.007901148	0.993354562	0.919137066	0.990145489	0.964772389	0.977770458
0.003043696	0.961052599	0.501057491	0.50958572	0.991847193	0.961998871	0.985182761	0.981754609	0.000436819	0.027574347	0.372827125	0.953528922	0.976348746	0.506488334	0.00924516	0.032276065	0.009029675	0.505290589	0.024104547	0.562624605	0.239641008	0.485709742	0.416078304	0.049608273	0.007455028	0.994019106	0.927210146	0.990378075	0.968290298	0.979993309
0.002789481	0.964278054	0.500951742	0.508627148	0.992013123	0.96508799	0.986664484	0.9835754	0.000397137	0.025592262	0.381759405	0.956640443	0.978713871	0.506003307	0.008829458	0.031436499	0.008126708	0.50476153	0.021744246	0.55867179	0.250076859	0.487138768	0.422214587	0.045399237	0.00706844	0.994617195	0.93447716	0.990592387	0.971456449	0.981993887
0.002561053	0.967180963	0.500856567	0.507764433	0.992160817	0.967871777	0.987998036	0.98521404	0.000361497	0.023797069	0.390175719	0.959530887	0.980842484	0.505551902	0.008465458	0.0308931	0.007314037	0.504285377	0.019620341	0.555010542	0.259849029	0.488424891	0.427962569	0.041597361	0.006734927	0.995155476	0.941018495	0.990789559	0.974306013	0.983794417
0.00235581	0.969793582	0.500770911	0.50698799	0.992292263	0.970380387	0.989198232	0.986688749	0.000329491	0.02217135	0.398090272	0.962211928	0.982758235	0.505132273	0.008147209	0.030622422	0.006582633	0.503856839	0.01770917	0.55162459	0.268890913	0.489582402	0.433338618	0.038163412	0.006448634	0.995639928	0.946906546	0.990970697	0.976870647	0.985414901
0.002171413	0.972144939	0.50069382	0.506289191	0.992409233	0.972641001	0.990278408	0.988015926	0.000300749	0.020699275	0.405519499	0.96469543	0.984482411	0.504742605	0.007869397	0.030601996	0.00592437	0.503471155	0.015989437	0.548497807	0.277151909	0.490624162	0.438359692	0.035061901	0.006204252	0.996075935	0.952206502	0.991136869	0.97917884	0.986873343
0.002005756	0.97426116	0.500624438	0.505660272	0.992513306	0.974678117	0.991250567	0.989210331	0.000274938	0.019366462	0.412481496	0.966993232	0.98603417	0.504381125	0.007627285	0.030810199	0.005331933	0.50312404	0.014441978	0.545614361	0.284596119	0.491561746	0.443043063	0.032260732	0.005996975	0.996468342	0.956977062	0.9912891	0.981256234	0.988185946
0.001856944	0.976165759	0.500561994	0.505094245	0.992605894	0.976513817	0.99212551	0.990285244	0.000251762	0.018159851	0.418995549	0.969116989	0.987430753	0.504046114	0.007416654	0.031226154	0.00479874	0.502811636	0.013049544	0.542958822	0.291201036	0.492405571	0.447406089	0.029730887	0.005822461	0.996821508	0.961271074	0.991428369	0.983125908	0.989367293
0.001723274	0.977879898	0.500505794	0.50458482	0.992688252	0.978168002	0.992912959	0.991252619	0.000230952	0.017067587	0.42508172	0.97107805	0.988687677	0.503735914	0.00723375	0.031829687	0.004318866	0.502530472	0.011796614	0.540516254	0.296956277	0.493165014	0.451466025	0.027446136	0.005676791	0.997139357	0.96513612	0.991555611	0.984808631	0.990430509
0.001603214	0.979422623	0.500455215	0.504126338	0.992761501	0.97965861	0.993621663	0.992123215	0.000212267	0.016078914	0.430760515	0.972887367	0.989818909	0.503448929	0.007075239	0.032601305	0.003886979	0.502277425	0.010669219	0.538272278	0.301862343	0.493848513	0.455239874	0.025382768	0.005556434	0.997425421	0.968615035	0.991671711	0.986323096	0.991387407
0.001495385	0.980811075	0.500409694	0.503713704	0.992826641	0.981001807	0.994259496	0.992906714	0.000195492	0.015184074	0.436052598	0.974555439	0.990837018	0.503183636	0.00693816	0.033522206	0.003498281	0.502049683	0.00965479	0.536213122	0.305929419	0.494463661	0.458744264	0.023519358	0.005458218	0.997682879	0.971746381	0.991777504	0.987686128	0.992248617
0.001398548	0.982060683	0.500368724	0.503342334	0.99288456	0.982212162	0.994833546	0.993611827	0.00018043	0.014374216	0.44097856	0.976092266	0.991753316	0.502938582	0.006819886	0.034574302	0.003148453	0.501844714	0.008742012	0.534325654	0.309176217	0.495017295	0.461995357	0.021836545	0.005379296	0.997914591	0.974564872	0.991873781	0.988912869	0.993023709
0.001311588	0.983185329	0.500331852	0.503008101	0.992936053	0.983302806	0.995350191	0.994246398	0.000166908	0.013641316	0.445558731	0.977507328	0.992577984	0.502712385	0.006718092	0.03574026	0.002833608	0.501660243	0.007920706	0.5325974	0.311628854	0.495515566	0.465008773	0.020316837	0.00531712	0.998123132	0.977101757	0.991961283	0.990016947	0.993721293
0.001233505	0.984197511	0.500298667	0.50270729	0.992981826	0.984285574	0.995815172	0.994817484	0.000154769	0.012978102	0.449813029	0.978809573	0.993320185	0.502503737	0.006630721	0.037003545	0.002550247	0.501494219	0.007181711	0.531016552	0.313319762	0.495964009	0.467799541	0.018944431	0.005269415	0.998310819	0.979385166	0.992040706	0.991010626	0.99434912
0.001163396	0.985108475	0.5002688	0.502436561	0.993022509	0.98517113	0.996233654	0.995331435	0.000143872	0.01237798	0.453760842	0.980007417	0.993988167	0.502311402	0.006555953	0.038348465	0.002295222	0.501344797	0.006516781	0.52957197	0.31428665	0.496367608	0.47038206	0.017705053	0.005234155	0.998479737	0.981440421	0.992112701	0.991904947	0.994914167
0.001100451	0.985928343	0.50024192	0.502192905	0.993058663	0.985969084	0.996610289	0.995793968	0.00013409	0.011834977	0.457420934	0.981108752	0.99458935	0.502134214	0.006492182	0.039760212	0.0020657	0.501210317	0.005918498	0.528253174	0.314571493	0.496730847	0.472770073	0.016585807	0.00520954	0.998631763	0.983290315	0.992177876	0.992709843	0.99542271
0.001043943	0.986666223	0.500217728	0.501973615	0.993090788	0.986688099	0.99694926	0.996210226	0.000125308	0.01134368	0.460811379	0.982120956	0.995130415	0.501971076	0.006437992	0.041224902	0.00185913	0.501089285	0.005380186	0.527050333	0.314219574	0.497057763	0.474976659	0.015575047	0.005193974	0.998768587	0.984955364	0.992236799	0.993434256	0.995880399
0.000993217	0.987330316	0.500195955	0.501776253	0.993119328	0.987335979	0.997254333	0.996584839	0.000117426	0.010899187	0.46394951	0.983050913	0.995617373	0.501820959	0.006392133	0.042729598	0.001673217	0.500980357	0.004895835	0.525954241	0.313278585	0.497351986	0.477014224	0.014662255	0.005186049	0.998891728	0.986454037	0.992289997	0.994086234	0.996292321
0.000947685	0.987927999	0.50017636	0.501598628	0.993144681	0.98791976	0.9975289	0.996921974	0.000110351	0.010497056	0.466851891	0.983905034	0.996055635	0.501682898	0.006353508	0.044262329	0.001505895	0.500882321	0.004460041	0.524956307	0.311797775	0.497616788	0.478894507	0.013837931	0.005184525	0.999002555	0.987802955	0.992337961	0.994673021	0.996663052];

d6=[0.10665277	0.961898081	0.004634224	0.774910465	0.817303221	0.868694705	0.084435846	0.399782649	0.259870403	0.80006848	0.431413827	0.910647594	0.181847028	0.263802917	0.14553898	0.136068559	0.869292208	0.579704587	0.549860202	0.144954798	0.853031118	0.622055131	0.350952381	0.51324954	0.401808034	0.075966692	0.239916154	0.123318935	0.183907788	0.239952526
0.097863579	0.965038988	0.054170802	0.747419418	0.835341514	0.876444034	0.175992209	0.459804366	0.307648648	0.818518253	0.388272445	0.916678589	0.263628644	0.33543481	0.130985308	0.13254044	0.782380727	0.571734129	0.496750267	0.211541973	0.773900407	0.609849618	0.315873917	0.498993222	0.380634345	0.168370022	0.21654184	0.137351315	0.233645151	0.313294316
0.088725872	0.967865804	0.098753722	0.722677476	0.851554774	0.884246386	0.258392958	0.513823897	0.323922685	0.832897921	0.349445203	0.920935899	0.337255637	0.400910558	0.117886965	0.124374266	0.704146111	0.564560716	0.447723892	0.269136633	0.703104284	0.598864657	0.284326519	0.477018431	0.353331622	0.251533019	0.196723494	0.156586781	0.294620024	0.378225461
0.080097201	0.970409938	0.138878349	0.700409729	0.866122607	0.891999952	0.332553644	0.562441454	0.315631045	0.841412586	0.314500694	0.92333926	0.40352663	0.460049529	0.106098431	0.11466904	0.633732292	0.558104644	0.403195419	0.31869742	0.640467873	0.588978191	0.255981275	0.450007463	0.324346933	0.326379713	0.182031519	0.183484479	0.357678977	0.435433291
0.072188084	0.972699659	0.174990514	0.680368756	0.879208797	0.899564329	0.399298268	0.606197226	0.295321191	0.84148833	0.283050683	0.923828332	0.463172665	0.513173516	0.095488738	0.104780956	0.570359274	0.55229418	0.362976479	0.361115538	0.58558835	0.580080372	0.230559738	0.42037975	0.295878126	0.393741735	0.17601212	0.218500838	0.418227654	0.485770063
0.065014646	0.974760408	0.207491463	0.66233188	0.890961631	0.906832522	0.459368433	0.645577381	0.27107938	0.8305831	0.25474586	0.922379454	0.516854856	0.560678532	0.085940013	0.095286613	0.51332341	0.547064762	0.326724202	0.397213685	0.53798185	0.572072335	0.207836053	0.389914111	0.268921284	0.454367551	0.184134897	0.260338297	0.47449233	0.530533383
0.058535435	0.976615082	0.236742317	0.646098692	0.901515	0.913735878	0.513431584	0.681019466	0.246585767	0.807545201	0.229272168	0.919019717	0.565169123	0.602925313	0.077346178	0.086417663	0.461991091	0.542358286	0.294074036	0.427745847	0.497129772	0.564865101	0.187638736	0.359793345	0.243877657	0.508930785	0.21070093	0.306740226	0.525990862	0.571538926
0.052693702	0.978284289	0.263068085	0.631488823	0.910989661	0.920235983	0.562088422	0.712917275	0.223301974	0.773437824	0.206347808	0.913837307	0.608652089	0.640217221	0.06961177	0.078250253	0.41579199	0.538122457	0.264678442	0.45339819	0.462496629	0.558378591	0.169850615	0.33075204	0.220858684	0.558037696	0.254537985	0.35534536	0.572779321	0.610317134
0.047431082	0.979786575	0.286761277	0.618339941	0.919494456	0.926316095	0.605879576	0.74162522	0.201741236	0.73105208	0.185721162	0.906987529	0.647786816	0.672804442	0.062650888	0.070789149	0.374212795	0.534310211	0.238217348	0.474791016	0.433539928	0.552540732	0.154405475	0.303215439	0.199835191	0.602233918	0.309335295	0.404195324	0.615125691	0.647135635
0.042692114	0.981138633	0.308085149	0.606505947	0.927127449	0.931974401	0.645291616	0.767462272	0.182023685	0.683700837	0.167169903	0.898694116	0.683008098	0.70089802	0.056386249	0.064006413	0.336791517	0.53087919	0.214399754	0.492481659	0.409718289	0.547286659	0.141280403	0.277403968	0.1807112	0.642010521	0.368035314	0.451881431	0.653371309	0.681465567
0.03842562	0.982355484	0.327276634	0.595855352	0.933976968	0.937219103	0.680762453	0.790715506	0.164107083	0.634286071	0.150501576	0.889245488	0.714707267	0.724687644	0.050748348	0.057859818	0.303112366	0.527791271	0.192962495	0.50696807	0.390499299	0.542557993	0.130483701	0.253405682	0.163361247	0.677809466	0.425856136	0.497492254	0.687871595	0.712920235
0.034584959	0.983450651	0.344548971	0.586269817	0.940122541	0.942064929	0.712686206	0.811643288	0.14788407	0.58495001	0.135555703	0.878985731	0.743236527	0.744359485	0.045674698	0.052301868	0.27280113	0.525012144	0.173668147	0.518692899	0.375367079	0.538302194	0.122039276	0.231224731	0.14764964	0.710028517	0.480413297	0.540497566	0.71897072	0.741460305
0.031127879	0.9844363	0.360094074	0.577642835	0.94563576	0.946530664	0.741417584	0.83047815	0.13322441	0.537106335	0.122207101	0.868300424	0.768912865	0.760111278	0.04110917	0.047284267	0.245521017	0.52251093	0.156302748	0.528047828	0.363829047	0.534471974	0.115969405	0.210813329	0.133440484	0.739025664	0.530789182	0.580635193	0.746991229	0.767240133
0.028016208	0.985323385	0.374084666	0.569878552	0.950581047	0.950637427	0.767275825	0.847429374	0.119993787	0.49160551	0.110369618	0.857598093	0.792021573	0.772162693	0.037001385	0.042760118	0.220968915	0.520259837	0.140673591	0.535378007	0.355421479	0.531024777	0.112278302	0.192092713	0.120602858	0.765123097	0.576791628	0.61782182	0.772230421	0.79048128
0.02521552	0.986121762	0.3866762	0.562890696	0.955016361	0.954407469	0.790548241	0.862685315	0.108062217	0.448904968	0.099999014	0.847288741	0.812819411	0.780760183	0.033306184	0.038684942	0.198872024	0.518233853	0.126607165	0.540986439	0.349713599	0.527922299	0.110938849	0.174966844	0.109013369	0.788610787	0.618553847	0.652088894	0.794959855	0.811415675
0.022694788	0.9868403	0.39800858	0.556601627	0.95899383	0.957863334	0.811493416	0.876415493	0.097307665	0.409202793	0.0910935	0.837761376	0.831537467	0.786176544	0.029983133	0.0350171	0.178984822	0.516410468	0.113947268	0.545138213	0.346310191	0.525130069	0.111884196	0.159331358	0.098557265	0.809749708	0.656343326	0.683538618	0.815426291	0.830264766
0.020426066	0.987486985	0.408207722	0.550941464	0.962560326	0.961027292	0.830344074	0.88877248	0.087617392	0.372532056	0.083690548	0.829362623	0.848383718	0.788706268	0.026996074	0.031717918	0.16108634	0.514769421	0.102553297	0.54806452	0.344852812	0.522617062	0.11500491	0.145079356	0.089128743	0.828774737	0.690473662	0.712314485	0.833853241	0.847232989
0.018384187	0.988069002	0.417386949	0.545847318	0.965757984	0.963920951	0.847309666	0.899893593	0.078888194	0.338824184	0.07785917	0.822378349	0.863545344	0.788658169	0.024312706	0.028751696	0.144977706	0.513292479	0.092298695	0.549966395	0.345019826	0.520355356	0.120151296	0.132105122	0.080630804	0.845897264	0.721264277	0.738581835	0.850442765	0.862506514
0.016546496	0.988592816	0.425648255	0.541262586	0.968624668	0.966565017	0.862578699	0.909902419	0.071026124	0.307950514	0.073687778	0.817019897	0.877190808	0.786346827	0.021904183	0.026085675	0.130479935	0.511963231	0.083069554	0.551018167	0.346525452	0.51831982	0.127139755	0.120306447	0.072974873	0.861307537	0.74902233	0.762515181	0.865377294	0.876253861
0.014892601	0.98906425	0.433083429	0.537136327	0.971194403	0.968979135	0.876320828	0.918910188	0.063945947	0.279749209	0.071268811	0.813416096	0.889471726	0.782084103	0.019744738	0.023690005	0.117431942	0.510766908	0.074763353	0.551370606	0.349118071	0.516487838	0.135761619	0.109586025	0.066080293	0.875176783	0.774035057	0.784290062	0.878821397	0.888627155
0.013404145	0.98948854	0.439775086	0.533422695	0.97349775	0.971181808	0.888688745	0.927017009	0.057570515	0.25404256	0.070682213	0.811611686	0.900524552	0.776171637	0.017811323	0.021537712	0.105688747	0.509690217	0.067287821	0.551153756	0.352577985	0.514839055	0.145792969	0.099852235	0.05987376	0.887659105	0.796567103	0.804077904	0.890923441	0.899763532
0.012064609	0.989870401	0.445797578	0.530080425	0.975562158	0.973190364	0.89981987	0.934312981	0.051830098	0.230647995	0.071980233	0.811572099	0.910472096	0.768894816	0.01608328	0.019604634	0.095119873	0.508721195	0.060559918	0.550479476	0.35671481	0.513355149	0.157004143	0.091019497	0.054288747	0.898893195	0.816860243	0.822042898	0.901817137	0.909786532
0.010859127	0.990214075	0.45121782	0.527072383	0.977412271	0.975020953	0.909837883	0.940879196	0.046661741	0.209385001	0.075175819	0.813193841	0.919424886	0.760518393	0.014542025	0.017869327	0.085607885	0.507849076	0.054504906	0.549443704	0.361364692	0.512019634	0.16916811	0.083008365	0.049264947	0.909003875	0.835134249	0.838340199	0.911622947	0.918807402
0.009774326	0.990523383	0.456096038	0.524365144	0.979070216	0.976688571	0.918854094	0.946788634	0.042008644	0.190079352	0.08023608	0.816318968	0.927482397	0.751283693	0.013170773	0.016312916	0.077047097	0.507064168	0.049055526	0.548128446	0.366387459	0.510817671	0.182067223	0.075745428	0.044747728	0.918103488	0.851588268	0.853115023	0.920449375	0.926926299
0.008798169	0.990801759	0.460486434	0.52192863	0.980555854	0.978207103	0.926968684	0.952106982	0.037819587	0.172565593	0.087081243	0.820751748	0.934734156	0.74140721	0.011954293	0.01491892	0.069342387	0.506357751	0.044151249	0.546603543	0.371663844	0.509735904	0.195498224	0.069163102	0.040687626	0.926293139	0.866402397	0.866502319	0.928394141	0.934233386
0.007919832	0.991052298	0.464437791	0.519735767	0.981887007	0.979589367	0.934271816	0.956893356	0.034048403	0.156688358	0.095588518	0.826275462	0.94126074	0.731080339	0.010878693	0.013673046	0.062408149	0.505721976	0.039737604	0.544928208	0.377092854	0.508762313	0.209275587	0.063199352	0.037039879	0.933663825	0.879739289	0.878626823	0.93554524	0.94080982
0.007129576	0.991277783	0.467994012	0.51776219	0.983079667	0.980847175	0.940844634	0.961200961	0.030653488	0.142302951	0.105599595	0.832667625	0.947134666	0.720469971	0.009931244	0.012562991	0.056167334	0.505149779	0.035765571	0.543152382	0.382589333	0.507886082	0.223233403	0.057797371	0.03376399	0.940297442	0.891745708	0.88960336	0.941981904	0.946728652
0.006418644	0.99148072	0.47119461	0.515985971	0.984148184	0.98199139	0.94676017	0.965077682	0.027597359	0.129275421	0.11693021	0.83971244	0.952421199	0.709719702	0.009100229	0.011578252	0.0505506	0.504634801	0.03219104	0.541317916	0.388081743	0.507097474	0.2372261	0.052905241	0.030823326	0.946267698	0.902554002	0.899537288	0.947775466	0.952055632
0.00577916	0.991663363	0.474075149	0.514387374	0.985105429	0.983031986	0.952084153	0.968566617	0.024846254	0.117482341	0.129380306	0.847209942	0.957179078	0.698951445	0.00837483	0.010709967	0.04549554	0.504171321	0.028974316	0.539459613	0.393510174	0.506387726	0.251128251	0.048475589	0.02818476	0.951640928	0.912283462	0.908525032	0.95299015	0.956849937
0.005204041	0.991827742	0.476667634	0.512948637	0.985962946	0.983978112	0.956875737	0.97170655	0.022369762	0.106810384	0.142743625	0.854981847	0.96146117	0.688267274	0.007745032	0.009950769	0.040945986	0.503754189	0.026079681	0.537606136	0.398824554	0.505748954	0.264833748	0.044465248	0.025818337	0.956476836	0.92104158	0.91665466	0.957683772	0.961164829
0.00468692	0.991975682	0.479000871	0.511653773	0.986731089	0.984838146	0.961188163	0.974532391	0.020140498	0.097155784	0.156815979	0.862874507	0.965315053	0.677751376	0.00720155	0.009294677	0.036851388	0.50337877	0.023474997	0.535780813	0.403983071	0.505174058	0.278254538	0.040834928	0.023696974	0.960829152	0.92892519	0.924006474	0.96190838	0.965048246
0.004222073	0.992108829	0.481100784	0.510488396	0.987419145	0.985619758	0.965069346	0.977075556	0.018133802	0.088423747	0.171401816	0.870759585	0.968783547	0.667472001	0.006735773	0.008736997	0.033166249	0.503040893	0.021131341	0.534002342	0.408950762	0.504656653	0.291319101	0.037548906	0.021796189	0.964746237	0.936021507	0.930653591	0.965710825	0.968543333
0.003804351	0.992228661	0.482990706	0.509439556	0.988035437	0.986329956	0.968562412	0.97936432	0.016327467	0.080527827	0.186319027	0.878533094	0.971905192	0.657483357	0.00633972	0.008274235	0.029849624	0.502736804	0.019022692	0.532285415	0.413698269	0.504190987	0.303970808	0.034574725	0.020093857	0.968271613	0.942409079	0.936662516	0.969133284	0.97168892
0.003429126	0.99233651	0.484691635	0.508495601	0.988587431	0.986975146	0.97170617	0.981424129	0.0147015	0.073389305	0.201402098	0.886113396	0.974714673	0.647827399	0.006006006	0.007904016	0.026864662	0.502463123	0.017125633	0.530641272	0.41820074	0.503771889	0.31616624	0.03188292	0.018569984	0.971444452	0.948158634	0.942093676	0.972213721	0.974519955
0.003092235	0.992433574	0.486222471	0.50764604	0.989081818	0.987561175	0.974535553	0.983277886	0.0132379	0.066936592	0.216503863	0.893438637	0.977243205	0.638535488	0.005727808	0.007625003	0.024178195	0.502216811	0.015419092	0.529078195	0.422436867	0.5033947	0.327873554	0.029446757	0.017206506	0.974300007	0.953333857	0.947001938	0.974986309	0.977067893
0.002789935	0.992520931	0.487600224	0.506881436	0.989524598	0.988093377	0.977081997	0.984946201	0.011920461	0.06110464	0.231496133	0.90046398	0.979518884	0.629629904	0.005498846	0.007436798	0.021760376	0.50199513	0.013884106	0.527601937	0.426388051	0.50305523	0.339070925	0.027241994	0.015987112	0.976870006	0.957992086	0.951437082	0.977481808	0.979361042
0.002518853	0.992599553	0.488840202	0.506193293	0.989921148	0.98857662	0.979373797	0.986447625	0.010734592	0.055834399	0.246269466	0.907158873	0.981566996	0.621125214	0.005313353	0.007339842	0.019584338	0.501795617	0.012503607	0.526216108	0.430037686	0.502749707	0.349745104	0.025246658	0.014897075	0.979183005	0.962184943	0.95544425	0.979727906	0.98142488
0.002275957	0.992670313	0.489956182	0.505573964	0.990276287	0.989015335	0.981436417	0.987798851	0.009667159	0.051072302	0.260732344	0.913504501	0.983410296	0.61302949	0.005166053	0.007335288	0.017625904	0.501616055	0.011262235	0.524922523	0.433370573	0.502474736	0.359890098	0.023440842	0.013923102	0.981264705	0.965958902	0.959064357	0.981749525	0.983282338
0.00205851	0.992733996	0.490960564	0.505016567	0.990594336	0.989413566	0.983292775	0.989014905	0.008706336	0.046769782	0.274809945	0.919491505	0.985069266	0.605345387	0.005052138	0.00742486	0.015863314	0.50145445	0.010146161	0.523721497	0.436372435	0.502227262	0.369505985	0.021806516	0.013053207	0.983138234	0.969355798	0.962334471	0.983569097	0.984954054
0.001864048	0.992791312	0.491864507	0.50451491	0.990879164	0.989774991	0.984963498	0.990109308	0.007841479	0.04288283	0.288442681	0.925117993	0.986562339	0.598071092	0.004967244	0.007610693	0.014276983	0.501309005	0.009142934	0.522612113	0.439029569	0.502004536	0.378597853	0.020327355	0.01227658	0.984824411	0.972413293	0.965288162	0.985206814	0.9864586
0.001690345	0.992842895	0.492678056	0.504063419	0.991134241	0.99010296	0.986467148	0.99109423	0.007063004	0.039371585	0.30158463	0.930387855	0.987906105	0.591201152	0.004907426	0.00789516	0.012849284	0.501178104	0.008241342	0.521592458	0.441328596	0.501804083	0.387174873	0.018988581	0.011583483	0.98634197	0.97516529	0.967955822	0.986680849	0.987812694
0.00153539	0.992889321	0.493410251	0.503657077	0.991362677	0.990400525	0.987820433	0.991980621	0.006362287	0.036199957	0.314201943	0.935309348	0.989115494	0.584727188	0.004869132	0.008280684	0.011564356	0.501060294	0.007431288	0.520659822	0.443256338	0.501623674	0.395249477	0.017776821	0.010965143	0.987707773	0.977642308	0.970364961	0.98800756	0.98903138
0.001397367	0.992931104	0.494069226	0.50329137	0.991567254	0.990670461	0.989038389	0.99277834	0.005731561	0.03333528	0.326271302	0.939893935	0.990203944	0.578638518	0.004849179	0.008769544	0.01040792	0.500954264	0.006703675	0.519810882	0.4447998	0.501461307	0.402836658	0.016679974	0.010413671	0.988936996	0.979871815	0.97254047	0.98920167	0.990128199
0.00127463	0.992968708	0.494662303	0.502962233	0.99175047	0.990915291	0.99013455	0.993496255	0.005163837	0.030747995	0.337778447	0.944155345	0.99118355	0.572922679	0.004844728	0.00936369	0.009367128	0.500858838	0.006050307	0.519041851	0.445946254	0.501315176	0.409953358	0.015687092	0.009921966	0.990043296	0.981878542	0.974504869	0.990276433	0.991115338
0.001165688	0.993002552	0.495196073	0.502666009	0.991914558	0.991137315	0.991121095	0.994142351	0.004652822	0.028411363	0.348716832	0.948108812	0.992065195	0.567565882	0.004853252	0.010064556	0.008430415	0.500772954	0.005463797	0.518348611	0.446683419	0.501183659	0.416617951	0.014788271	0.009483652	0.991038966	0.983684745	0.976278526	0.991243774	0.992003764
0.001069189	0.993033012	0.495676466	0.502399409	0.992061523	0.991338619	0.992008985	0.994723812	0.004192854	0.026301201	0.359086381	0.951770483	0.992858675	0.562553394	0.00487252	0.010872901	0.007587374	0.500695659	0.004937488	0.517726825	0.446999722	0.501065293	0.4228498	0.013974553	0.009093001	0.99193507	0.985310459	0.977879864	0.992114431	0.992803348
0.000983907	0.993060426	0.496108819	0.502159468	0.992193156	0.991521105	0.992808086	0.995247103	0.003778832	0.02439564	0.368892389	0.955156944	0.993572807	0.557869857	0.004900567	0.011788668	0.006828637	0.500626093	0.004465376	0.517172032	0.446884622	0.500958763	0.428668886	0.013237836	0.008744874	0.992741563	0.986773718	0.979325536	0.992898067	0.993522975
0.000908728	0.993085098	0.496497937	0.501943521	0.992311065	0.9916865	0.993527277	0.995718045	0.003406169	0.02267491	0.378144533	0.958284863	0.994215526	0.553499554	0.004935671	0.012810875	0.006145773	0.500563484	0.00404205	0.516679725	0.44632898	0.500862887	0.434095501	0.012570791	0.008434665	0.993467407	0.988090756	0.980630602	0.993603379	0.994170641
0.000842639	0.993107303	0.496848143	0.501749169	0.992416687	0.991836373	0.994174549	0.996141874	0.003070733	0.021121138	0.386856013	0.961170713	0.994793973	0.549426634	0.00497633	0.013937539	0.005531196	0.500507135	0.003662628	0.51624542	0.445325458	0.500776598	0.439149991	0.011966792	0.008158245	0.994120666	0.989276181	0.981808674	0.994238195	0.99475354
0.00078472	0.993127288	0.497163329	0.501574252	0.992511312	0.991972153	0.994757094	0.996523303	0.002768806	0.019718172	0.395042794	0.963830571	0.995314576	0.545635292	0.005021244	0.015165638	0.004978076	0.500456422	0.00332271	0.515864704	0.443868918	0.500698939	0.443852545	0.011419844	0.007911921	0.994708599	0.990343146	0.982872055	0.994809561	0.99527815];


dt=1;
   sum2=0;
    for i=1:49
        z1=0;
        for j=1:3
         z1=z1+u(j)*d2(i,sf(j));
        end
         f=1/(1+exp(-(z1+u(4))));
         x =(dt/u(5))*f+(1-dt/u(5))*d2(i,gn);
        sum2=sum2+(d2(i+1,gn)-x)^2;
   end;
   
    sum3=0;
    for i=1:49
        z1=0;
        for j=1:3
         z1=z1+u(j)*d3(i,sf(j));
        end
         f=1/(1+exp(-(z1+u(4))));
         x =(dt/u(5))*f+(1-dt/u(5))*d3(i,gn);
        sum3=sum3+(d3(i+1,gn)-x)^2;
   end;
   
      sum4=0;
    for i=1:49
        z1=0;
        for j=1:3
         z1=z1+u(j)*d4(i,sf(j));
        end
         f=1/(1+exp(-(z1+u(4))));
         x =(dt/u(5))*f+(1-dt/u(5))*d4(i,gn);
        sum4=sum4+(d4(i+1,gn)-x)^2;
   end;
     sum5=0;
    for i=1:49
        z1=0;
        for j=1:3
         z1=z1+u(j)*d5(i,sf(j));
        end
         f=1/(1+exp(-(z1+u(4))));
         x =(dt/u(5))*f+(1-dt/u(5))*d5(i,gn);
        sum5=sum5+(d5(i+1,gn)-x)^2;
   end;
    sum6=0;
   for i=1:49
        z1=0;
        for j=1:3
         z1=z1+u(j)*d6(i,sf(j));
        end
         f=1/(1+exp(-(z1+u(4))));
         x =(dt/u(5))*f+(1-dt/u(5))*d6(i,gn);
        sum6=sum6+(d6(i+1,gn)-x)^2;
   end;
   
     sum=sum2+sum3+sum4+sum5+sum6;
     z=sum;


